!SURFEX_LIC Copyright 1994-2014 Meteo-France 
!SURFEX_LIC This is part of the SURFEX software governed by the CeCILL-C  licence
!SURFEX_LIC version 1. See LICENSE, CeCILL-C_V1-en.txt and CeCILL-C_V1-fr.txt
!SURFEX_LIC for details. version 1.
!     ##################
      MODULE MODD_DATA_ISBA_n
!     ##################
!
!!****  *MODD_DATA_ISBA - declaration of DATA surface parameters for ISBA scheme
!!
!!    PURPOSE
!!    -------
!
!!
!!**  IMPLICIT ARGUMENTS
!!    ------------------
!!      None 
!!
!!    REFERENCE
!!    ---------
!!
!!    AUTHOR
!!    ------
!!	V. Masson  *Meteo France*
!!
!!    MODIFICATIONS
!!    -------------
!!      Original       05/2005
!
!*       0.   DECLARATIONS
!             ------------
!
!
!
USE YOMHOOK   ,ONLY : LHOOK,   DR_HOOK
USE PARKIND1  ,ONLY : JPRB
!
IMPLICIT NONE

TYPE DATA_ISBA_t
!-------------------------------------------------------------------------------
!
! Mask and number of grid elements containing patches/tiles:
!
  REAL, POINTER, DIMENSION(:,:)  :: XPAR_VEGTYPE       ! fraction of each vegetation type for
!                                                  ! each grid mesh                          (-)
!
!-------------------------------------------------------------------------------
!
  INTEGER                       :: NTIME               ! number of time data
!                                                      ! for VEG, LAI, EMIS, Z0
  LOGICAL                        :: LDATA_MIXPAR
!
  LOGICAL                        :: LDATA_VEGTYPE
  LOGICAL                        :: LDATA_LAI
  LOGICAL                        :: LDATA_H_TREE
  LOGICAL                        :: LDATA_DG
  LOGICAL                        :: LDATA_DICE  
  LOGICAL                        :: LDATA_ROOTFRAC
  LOGICAL                        :: LDATA_GROUND_DEPTH
  LOGICAL                        :: LDATA_ROOT_DEPTH
  LOGICAL                        :: LDATA_ROOT_EXTINCTION
  LOGICAL                        :: LDATA_ROOT_LIN
  LOGICAL                        :: LDATA_VEG
  LOGICAL                        :: LDATA_Z0
  LOGICAL                        :: LDATA_EMIS
  LOGICAL                        :: LDATA_ALBNIR_VEG
  LOGICAL                        :: LDATA_ALBVIS_VEG
  LOGICAL                        :: LDATA_ALBUV_VEG
  LOGICAL                        :: LDATA_RSMIN
  LOGICAL                        :: LDATA_GAMMA
  LOGICAL                        :: LDATA_WRMAX_CF
  LOGICAL                        :: LDATA_CV
  LOGICAL                        :: LDATA_Z0_O_Z0H
  LOGICAL                        :: LDATA_RGL
  LOGICAL                        :: LDATA_BSLAI
  LOGICAL                        :: LDATA_LAIMIN
  LOGICAL                        :: LDATA_SEFOLD
  LOGICAL                        :: LDATA_GMES
  LOGICAL                        :: LDATA_RE25
  LOGICAL                        :: LDATA_STRESS
  LOGICAL                        :: LDATA_F2I
  LOGICAL                        :: LDATA_GC
  LOGICAL                        :: LDATA_DMAX
  LOGICAL                        :: LDATA_CE_NITRO
  LOGICAL                        :: LDATA_CF_NITRO
  LOGICAL                        :: LDATA_CNA_NITRO
  LOGICAL                        :: LDATA_ALBNIR_SOIL
  LOGICAL                        :: LDATA_ALBVIS_SOIL
  LOGICAL                        :: LDATA_ALBUV_SOIL
  LOGICAL                        :: LDATA_IRRIG
  LOGICAL                        :: LDATA_WATSUP
!  
! Input Parameters, per patch:
!
! - vegetation + bare soil:
!
  REAL, POINTER, DIMENSION(:,:) :: XPAR_Z0_O_Z0H         ! ratio of surface roughness lengths
!                                                      ! (momentum to heat)                      (-)
  REAL, POINTER, DIMENSION(:,:,:) :: XPAR_EMIS             ! surface emissivity                      (-)
  REAL, POINTER, DIMENSION(:,:,:) :: XPAR_Z0               ! surface roughness length                (m)
!
! - vegetation:
!
  REAL, POINTER, DIMENSION(:,:) :: XPAR_ALBNIR_VEG       ! vegetation near-infra-red albedo        (-)
  REAL, POINTER, DIMENSION(:,:) :: XPAR_ALBVIS_VEG       ! vegetation visible albedo               (-)
  REAL, POINTER, DIMENSION(:,:) :: XPAR_ALBUV_VEG        ! vegetation UV albedo                    (-)
!
! - vegetation: default option (Jarvis) and general parameters:
!
  REAL, POINTER, DIMENSION(:,:,:) :: XPAR_VEG            ! vegetation cover fraction               (-)
  REAL, POINTER, DIMENSION(:,:) :: XPAR_WRMAX_CF         ! coefficient for maximum water 
!                                                      ! interception 
!                                                      ! storage capacity on the vegetation      (-)
  REAL, POINTER, DIMENSION(:,:) :: XPAR_RSMIN            ! minimum stomatal resistance             (s/m)
  REAL, POINTER, DIMENSION(:,:) :: XPAR_GAMMA            ! coefficient for the calculation
!                                                      ! of the surface stomatal
!                                                      ! resistance
  REAL, POINTER, DIMENSION(:,:) :: XPAR_CV               ! vegetation thermal inertia coefficient  (K m2/J)
  REAL, POINTER, DIMENSION(:,:) :: XPAR_RGL              ! maximum solar radiation
!                                                      ! usable in photosynthesis                (W/m2)
  REAL, POINTER, DIMENSION(:,:,:) :: XPAR_ROOTFRAC       ! root fraction profile ('DIF' option)
!
  REAL, POINTER, DIMENSION(:,:) :: XPAR_ROOT_DEPTH       ! root depth ('DIF' option)
  REAL, POINTER, DIMENSION(:,:) :: XPAR_ROOT_EXTINCTION  ! root extinction parameter ('DIF' option)
  REAL, POINTER, DIMENSION(:,:) :: XPAR_ROOT_LIN         ! root linear parameter ('DIF' option)
!  
!-------------------------------------------------------------------------------
!
! - vegetation: Ags parameters ('AGS', 'LAI', 'AST', 'LST', 'NIT', 'NCB' options)
!
  REAL, POINTER, DIMENSION(:,:)    :: XPAR_BSLAI        ! ratio d(biomass)/d(lai)                 (kg/m2)
  REAL, POINTER, DIMENSION(:,:)    :: XPAR_LAIMIN       ! minimum LAI (Leaf Area Index)           (m2/m2)
  REAL, POINTER, DIMENSION(:,:)    :: XPAR_SEFOLD       ! e-folding time for senescence           (s)
  REAL, POINTER, DIMENSION(:,:)    :: XPAR_H_TREE       ! height of trees                         (m)
  REAL, POINTER, DIMENSION(:,:)    :: XPAR_GMES         ! mesophyll conductance                   (m s-1)
  REAL, POINTER, DIMENSION(:,:)    :: XPAR_RE25         ! Ecosystem respiration parameter         (kg m2 s-1)
!
!-------------------------------------------------------------------------------
!
! - vegetation: Ags Stress parameters ('AST', 'LST', 'NIT', 'NCB' options)
!
  LOGICAL, POINTER, DIMENSION(:,:) :: LPAR_STRESS       ! vegetation response type to water
!                                                     ! stress (true:defensive false:offensive) (-)
  REAL, POINTER, DIMENSION(:,:)    :: XPAR_F2I          ! critical normilized soil water 
!                                                     ! content for stress parameterisation
  REAL, POINTER, DIMENSION(:,:)    :: XPAR_GC           ! cuticular conductance                   (m s-1)
  REAL, POINTER, DIMENSION(:,:)    :: XPAR_DMAX         ! maximum air saturation deficit
!                                                     ! tolerate by vegetation                  (kg/kg)
!
!-------------------------------------------------------------------------------
!
! - vegetation: Ags Nitrogen-model parameters ('NIT', 'NCB' option)
!
  REAL, POINTER, DIMENSION(:,:)    :: XPAR_CE_NITRO       ! leaf aera ratio sensitivity to 
!                                                       ! nitrogen concentration                (m2/kg)
  REAL, POINTER, DIMENSION(:,:)    :: XPAR_CF_NITRO       ! lethal minimum value of leaf area
!                                                       ! ratio                                 (m2/kg)
  REAL, POINTER, DIMENSION(:,:)    :: XPAR_CNA_NITRO      ! nitrogen concentration of active 
!                                                       ! biomass                               (kg/kg)
!
!-------------------------------------------------------------------------------
!
! - soil: primary parameters
!
  REAL, POINTER, DIMENSION(:,:,:)  :: XPAR_DG          ! soil layer depth                        (m)
!                                                      ! NOTE: in Force-Restore mode, the 
!                                                      ! uppermost layer thickness is superficial
!                                                      ! and is only explicitly used for soil 
!                                                      ! water phase changes                     (m)
!
  REAL, POINTER,DIMENSION(:,:)     :: XPAR_GROUND_DEPTH ! ground depth (DIF option)
!
  REAL, POINTER,DIMENSION(:,:)     :: XPAR_DICE        ! depth of the soil column for the calculation
!                                                        of the frozen soil fraction (m) (Force restore)
!
! - bare soil albedo
!
  REAL, POINTER, DIMENSION(:,:) :: XPAR_ALBNIR_SOIL      ! soil near-infra-red albedo        (-)
  REAL, POINTER, DIMENSION(:,:) :: XPAR_ALBVIS_SOIL      ! soil visible albedo               (-)
  REAL, POINTER, DIMENSION(:,:) :: XPAR_ALBUV_SOIL       ! soil UV albedo                    (-)
!
!-------------------------------------------------------------------------------
!
! - Vegetation: Ags Prognostic (YPHOTO = ('LAI', 'LST', 'NIT', or 'NCB') or prescribed (YPHOTO='NON', 'AGS' or 'AST')
!
  REAL, POINTER, DIMENSION(:,:,:)     :: XPAR_LAI          ! Leaf Area Index                         (m2/m2)
!
  REAL, POINTER, DIMENSION(:,:,:)     :: XPAR_IRRIG
  REAL, POINTER, DIMENSION(:,:,:)     :: XPAR_WATSUP
!
!-------------------------------------------------------------------------------
!

END TYPE DATA_ISBA_t

TYPE(DATA_ISBA_t), ALLOCATABLE, TARGET, SAVE :: DATA_ISBA_MODEL(:)

INTEGER, POINTER :: NTIME=>NULL()
!$OMP THREADPRIVATE(NTIME)
LOGICAL, POINTER :: LDATA_MIXPAR=>NULL()
!$OMP THREADPRIVATE(LDATA_MIXPAR)
LOGICAL, POINTER :: LDATA_VEGTYPE=>NULL()
!$OMP THREADPRIVATE(LDATA_VEGTYPE)
LOGICAL, POINTER:: LDATA_LAI=>NULL()
!$OMP THREADPRIVATE(LDATA_LAI)
LOGICAL, POINTER:: LDATA_H_TREE=>NULL()
!$OMP THREADPRIVATE(LDATA_H_TREE)
LOGICAL, POINTER:: LDATA_DG=>NULL()
!$OMP THREADPRIVATE(LDATA_DG)
LOGICAL, POINTER:: LDATA_DICE=>NULL()
!$OMP THREADPRIVATE(LDATA_DICE)
LOGICAL, POINTER:: LDATA_GROUND_DEPTH=>NULL()
!$OMP THREADPRIVATE(LDATA_GROUND_DEPTH)
LOGICAL, POINTER:: LDATA_ROOT_DEPTH=>NULL()
!$OMP THREADPRIVATE(LDATA_ROOT_DEPTH)
LOGICAL, POINTER:: LDATA_ROOT_EXTINCTION=>NULL()
!$OMP THREADPRIVATE(LDATA_ROOT_EXTINCTION)
LOGICAL, POINTER:: LDATA_ROOT_LIN=>NULL()
!$OMP THREADPRIVATE(LDATA_ROOT_LIN)
LOGICAL, POINTER:: LDATA_ROOTFRAC=>NULL()
!$OMP THREADPRIVATE(LDATA_ROOTFRAC)
LOGICAL, POINTER:: LDATA_VEG=>NULL()
!$OMP THREADPRIVATE(LDATA_VEG)
LOGICAL, POINTER:: LDATA_Z0=>NULL()
!$OMP THREADPRIVATE(LDATA_Z0)
LOGICAL, POINTER:: LDATA_EMIS=>NULL()
!$OMP THREADPRIVATE(LDATA_EMIS)
LOGICAL, POINTER:: LDATA_ALBNIR_VEG=>NULL()
!$OMP THREADPRIVATE(LDATA_ALBNIR_VEG)
LOGICAL, POINTER:: LDATA_ALBVIS_VEG=>NULL()
!$OMP THREADPRIVATE(LDATA_ALBVIS_VEG)
LOGICAL, POINTER:: LDATA_ALBUV_VEG=>NULL()
!$OMP THREADPRIVATE(LDATA_ALBUV_VEG)
LOGICAL, POINTER:: LDATA_RSMIN=>NULL()
!$OMP THREADPRIVATE(LDATA_RSMIN)
LOGICAL, POINTER:: LDATA_GAMMA=>NULL()
!$OMP THREADPRIVATE(LDATA_GAMMA)
LOGICAL, POINTER:: LDATA_WRMAX_CF=>NULL()
!$OMP THREADPRIVATE(LDATA_WRMAX_CF)
LOGICAL, POINTER:: LDATA_CV=>NULL()
!$OMP THREADPRIVATE(LDATA_CV)
LOGICAL, POINTER:: LDATA_RGL=>NULL()
!$OMP THREADPRIVATE(LDATA_RGL)
LOGICAL, POINTER:: LDATA_Z0_O_Z0H=>NULL()
!$OMP THREADPRIVATE(LDATA_Z0_O_Z0H)
LOGICAL, POINTER:: LDATA_BSLAI=>NULL()
!$OMP THREADPRIVATE(LDATA_BSLAI)
LOGICAL, POINTER:: LDATA_LAIMIN=>NULL()
!$OMP THREADPRIVATE(LDATA_LAIMIN)
LOGICAL, POINTER:: LDATA_SEFOLD=>NULL()
!$OMP THREADPRIVATE(LDATA_SEFOLD)
LOGICAL, POINTER:: LDATA_GMES=>NULL()
!$OMP THREADPRIVATE(LDATA_GMES)
LOGICAL, POINTER:: LDATA_RE25=>NULL()
!$OMP THREADPRIVATE(LDATA_RE25)
LOGICAL, POINTER:: LDATA_STRESS=>NULL()
!$OMP THREADPRIVATE(LDATA_STRESS)
LOGICAL, POINTER:: LDATA_F2I=>NULL()
!$OMP THREADPRIVATE(LDATA_F2I)
LOGICAL, POINTER:: LDATA_GC=>NULL()
!$OMP THREADPRIVATE(LDATA_GC)
LOGICAL, POINTER:: LDATA_DMAX=>NULL()
!$OMP THREADPRIVATE(LDATA_DMAX)
LOGICAL, POINTER:: LDATA_CE_NITRO=>NULL()
!$OMP THREADPRIVATE(LDATA_CE_NITRO)
LOGICAL, POINTER:: LDATA_CF_NITRO=>NULL()
!$OMP THREADPRIVATE(LDATA_CF_NITRO)
LOGICAL, POINTER:: LDATA_CNA_NITRO=>NULL()
!$OMP THREADPRIVATE(LDATA_CNA_NITRO)
LOGICAL, POINTER:: LDATA_ALBNIR_SOIL=>NULL()
!$OMP THREADPRIVATE(LDATA_ALBNIR_SOIL)
LOGICAL, POINTER:: LDATA_ALBVIS_SOIL=>NULL()
!$OMP THREADPRIVATE(LDATA_ALBVIS_SOIL)
LOGICAL, POINTER:: LDATA_ALBUV_SOIL=>NULL()
!$OMP THREADPRIVATE(LDATA_ALBUV_SOIL)
LOGICAL, POINTER:: LDATA_IRRIG=>NULL()
!$OMP THREADPRIVATE(LDATA_IRRIG)
LOGICAL, POINTER:: LDATA_WATSUP=>NULL()
!$OMP THREADPRIVATE(LDATA_WATSUP)
REAL, POINTER, DIMENSION(:,:)    :: XPAR_VEGTYPE=>NULL()
!$OMP THREADPRIVATE(XPAR_VEGTYPE)
REAL, POINTER, DIMENSION(:,:) :: XPAR_Z0_O_Z0H=>NULL()
!$OMP THREADPRIVATE(XPAR_Z0_O_Z0H)
REAL, POINTER, DIMENSION(:,:,:) :: XPAR_EMIS=>NULL()
!$OMP THREADPRIVATE(XPAR_EMIS)
REAL, POINTER, DIMENSION(:,:,:) :: XPAR_Z0=>NULL()
!$OMP THREADPRIVATE(XPAR_Z0)
REAL, POINTER, DIMENSION(:,:) :: XPAR_ALBNIR_VEG=>NULL()
!$OMP THREADPRIVATE(XPAR_ALBNIR_VEG)
REAL, POINTER, DIMENSION(:,:) :: XPAR_ALBVIS_VEG=>NULL()
!$OMP THREADPRIVATE(XPAR_ALBVIS_VEG)
REAL, POINTER, DIMENSION(:,:) :: XPAR_ALBUV_VEG=>NULL()
!$OMP THREADPRIVATE(XPAR_ALBUV_VEG)
REAL, POINTER, DIMENSION(:,:) :: XPAR_ALBNIR_SOIL=>NULL()
!$OMP THREADPRIVATE(XPAR_ALBNIR_SOIL)
REAL, POINTER, DIMENSION(:,:) :: XPAR_ALBVIS_SOIL=>NULL()
!$OMP THREADPRIVATE(XPAR_ALBVIS_SOIL)
REAL, POINTER, DIMENSION(:,:) :: XPAR_ALBUV_SOIL=>NULL()
!$OMP THREADPRIVATE(XPAR_ALBUV_SOIL)
REAL, POINTER, DIMENSION(:,:,:) :: XPAR_VEG=>NULL()
!$OMP THREADPRIVATE(XPAR_VEG)
REAL, POINTER, DIMENSION(:,:) :: XPAR_WRMAX_CF=>NULL()
!$OMP THREADPRIVATE(XPAR_WRMAX_CF)
REAL, POINTER, DIMENSION(:,:) :: XPAR_RSMIN=>NULL()
!$OMP THREADPRIVATE(XPAR_RSMIN)
REAL, POINTER, DIMENSION(:,:) :: XPAR_GAMMA=>NULL()
!$OMP THREADPRIVATE(XPAR_GAMMA)
REAL, POINTER, DIMENSION(:,:) :: XPAR_CV=>NULL()
!$OMP THREADPRIVATE(XPAR_CV)
REAL, POINTER, DIMENSION(:,:) :: XPAR_RGL=>NULL()
!$OMP THREADPRIVATE(XPAR_RGL)
REAL, POINTER, DIMENSION(:,:,:) :: XPAR_ROOTFRAC=>NULL()
!$OMP THREADPRIVATE(XPAR_ROOTFRAC)
REAL, POINTER, DIMENSION(:,:)    :: XPAR_BSLAI=>NULL()
!$OMP THREADPRIVATE(XPAR_BSLAI)
REAL, POINTER, DIMENSION(:,:)    :: XPAR_LAIMIN=>NULL()
!$OMP THREADPRIVATE(XPAR_LAIMIN)
REAL, POINTER, DIMENSION(:,:)    :: XPAR_SEFOLD=>NULL()
!$OMP THREADPRIVATE(XPAR_SEFOLD)
REAL, POINTER, DIMENSION(:,:)    :: XPAR_H_TREE=>NULL()
!$OMP THREADPRIVATE(XPAR_H_TREE)
REAL, POINTER, DIMENSION(:,:)    :: XPAR_GMES=>NULL()
!$OMP THREADPRIVATE(XPAR_GMES)
REAL, POINTER, DIMENSION(:,:)    :: XPAR_RE25=>NULL()
!$OMP THREADPRIVATE(XPAR_RE25)
LOGICAL, POINTER, DIMENSION(:,:) :: LPAR_STRESS=>NULL()
!$OMP THREADPRIVATE(LPAR_STRESS)
REAL, POINTER, DIMENSION(:,:)    :: XPAR_F2I=>NULL()
!$OMP THREADPRIVATE(XPAR_F2I)
REAL, POINTER, DIMENSION(:,:)    :: XPAR_GC=>NULL()
!$OMP THREADPRIVATE(XPAR_GC)
REAL, POINTER, DIMENSION(:,:)    :: XPAR_DMAX=>NULL()
!$OMP THREADPRIVATE(XPAR_DMAX)
REAL, POINTER, DIMENSION(:,:)    :: XPAR_CE_NITRO=>NULL()
!$OMP THREADPRIVATE(XPAR_CE_NITRO)
REAL, POINTER, DIMENSION(:,:)    :: XPAR_CF_NITRO=>NULL()
!$OMP THREADPRIVATE(XPAR_CF_NITRO)
REAL, POINTER, DIMENSION(:,:)    :: XPAR_CNA_NITRO=>NULL()
!$OMP THREADPRIVATE(XPAR_CNA_NITRO)
REAL, POINTER, DIMENSION(:,:,:)  :: XPAR_DG=>NULL()
!$OMP THREADPRIVATE(XPAR_DG)
REAL, POINTER, DIMENSION(:,:)    :: XPAR_DICE=>NULL()
!$OMP THREADPRIVATE(XPAR_DICE)
REAL, POINTER, DIMENSION(:,:)    :: XPAR_GROUND_DEPTH=>NULL()
!$OMP THREADPRIVATE(XPAR_GROUND_DEPTH)
REAL, POINTER, DIMENSION(:,:)    :: XPAR_ROOT_DEPTH=>NULL()
!$OMP THREADPRIVATE(XPAR_ROOT_DEPTH)
REAL, POINTER, DIMENSION(:,:)    :: XPAR_ROOT_EXTINCTION=>NULL()
!$OMP THREADPRIVATE(XPAR_ROOT_EXTINCTION)
REAL, POINTER, DIMENSION(:,:)    :: XPAR_ROOT_LIN=>NULL()
!$OMP THREADPRIVATE(XPAR_ROOT_LIN)
REAL, POINTER, DIMENSION(:,:,:)     :: XPAR_LAI=>NULL()
!$OMP THREADPRIVATE(XPAR_LAI)
REAL, POINTER, DIMENSION(:,:,:)     :: XPAR_IRRIG=>NULL()
!$OMP THREADPRIVATE(XPAR_IRRIG)
REAL, POINTER, DIMENSION(:,:,:)     :: XPAR_WATSUP=>NULL()
!$OMP THREADPRIVATE(XPAR_WATSUP)

CONTAINS

SUBROUTINE DATA_ISBA_GOTO_MODEL(KFROM, KTO, LKFROM)
LOGICAL, INTENT(IN) :: LKFROM
INTEGER, INTENT(IN) :: KFROM, KTO
REAL(KIND=JPRB) :: ZHOOK_HANDLE
!
! Save current state for allocated arrays
IF (LKFROM) THEN
DATA_ISBA_MODEL(KFROM)%XPAR_VEGTYPE=>XPAR_VEGTYPE
DATA_ISBA_MODEL(KFROM)%XPAR_Z0_O_Z0H=>XPAR_Z0_O_Z0H
DATA_ISBA_MODEL(KFROM)%XPAR_EMIS=>XPAR_EMIS
DATA_ISBA_MODEL(KFROM)%XPAR_Z0=>XPAR_Z0
DATA_ISBA_MODEL(KFROM)%XPAR_ALBNIR_VEG=>XPAR_ALBNIR_VEG
DATA_ISBA_MODEL(KFROM)%XPAR_ALBVIS_VEG=>XPAR_ALBVIS_VEG
DATA_ISBA_MODEL(KFROM)%XPAR_ALBUV_VEG=>XPAR_ALBUV_VEG
DATA_ISBA_MODEL(KFROM)%XPAR_ALBNIR_SOIL=>XPAR_ALBNIR_SOIL
DATA_ISBA_MODEL(KFROM)%XPAR_ALBVIS_SOIL=>XPAR_ALBVIS_SOIL
DATA_ISBA_MODEL(KFROM)%XPAR_ALBUV_SOIL=>XPAR_ALBUV_SOIL
DATA_ISBA_MODEL(KFROM)%XPAR_VEG=>XPAR_VEG
DATA_ISBA_MODEL(KFROM)%XPAR_WRMAX_CF=>XPAR_WRMAX_CF
DATA_ISBA_MODEL(KFROM)%XPAR_RSMIN=>XPAR_RSMIN
DATA_ISBA_MODEL(KFROM)%XPAR_GAMMA=>XPAR_GAMMA
DATA_ISBA_MODEL(KFROM)%XPAR_CV=>XPAR_CV
DATA_ISBA_MODEL(KFROM)%XPAR_RGL=>XPAR_RGL
DATA_ISBA_MODEL(KFROM)%XPAR_Z0_O_Z0H=>XPAR_Z0_O_Z0H
DATA_ISBA_MODEL(KFROM)%XPAR_ROOTFRAC=>XPAR_ROOTFRAC
DATA_ISBA_MODEL(KFROM)%XPAR_BSLAI=>XPAR_BSLAI
DATA_ISBA_MODEL(KFROM)%XPAR_LAIMIN=>XPAR_LAIMIN
DATA_ISBA_MODEL(KFROM)%XPAR_SEFOLD=>XPAR_SEFOLD
DATA_ISBA_MODEL(KFROM)%XPAR_H_TREE=>XPAR_H_TREE
DATA_ISBA_MODEL(KFROM)%XPAR_GMES=>XPAR_GMES
DATA_ISBA_MODEL(KFROM)%XPAR_RE25=>XPAR_RE25
DATA_ISBA_MODEL(KFROM)%LPAR_STRESS=>LPAR_STRESS
DATA_ISBA_MODEL(KFROM)%XPAR_F2I=>XPAR_F2I
DATA_ISBA_MODEL(KFROM)%XPAR_GC=>XPAR_GC
DATA_ISBA_MODEL(KFROM)%XPAR_DMAX=>XPAR_DMAX
DATA_ISBA_MODEL(KFROM)%XPAR_CE_NITRO=>XPAR_CE_NITRO
DATA_ISBA_MODEL(KFROM)%XPAR_CF_NITRO=>XPAR_CF_NITRO
DATA_ISBA_MODEL(KFROM)%XPAR_CNA_NITRO=>XPAR_CNA_NITRO
DATA_ISBA_MODEL(KFROM)%XPAR_DG=>XPAR_DG
DATA_ISBA_MODEL(KFROM)%XPAR_DICE=>XPAR_DICE
DATA_ISBA_MODEL(KFROM)%XPAR_GROUND_DEPTH=>XPAR_GROUND_DEPTH
DATA_ISBA_MODEL(KFROM)%XPAR_ROOT_DEPTH=>XPAR_ROOT_DEPTH
DATA_ISBA_MODEL(KFROM)%XPAR_ROOT_EXTINCTION=>XPAR_ROOT_EXTINCTION
DATA_ISBA_MODEL(KFROM)%XPAR_ROOT_LIN=>XPAR_ROOT_LIN
DATA_ISBA_MODEL(KFROM)%XPAR_LAI=>XPAR_LAI
DATA_ISBA_MODEL(KFROM)%XPAR_IRRIG=>XPAR_IRRIG
DATA_ISBA_MODEL(KFROM)%XPAR_WATSUP=>XPAR_WATSUP
ENDIF
!
! Current model is set to model KTO
IF (LHOOK) CALL DR_HOOK('MODD_DATA_ISBA_N:DATA_ISBA_GOTO_MODEL',0,ZHOOK_HANDLE)
NTIME=>DATA_ISBA_MODEL(KTO)%NTIME
LDATA_MIXPAR=>DATA_ISBA_MODEL(KTO)%LDATA_MIXPAR
LDATA_VEGTYPE=>DATA_ISBA_MODEL(KTO)%LDATA_VEGTYPE
LDATA_LAI=>DATA_ISBA_MODEL(KTO)%LDATA_LAI
LDATA_H_TREE=>DATA_ISBA_MODEL(KTO)%LDATA_H_TREE
LDATA_DG=>DATA_ISBA_MODEL(KTO)%LDATA_DG
LDATA_DICE=>DATA_ISBA_MODEL(KTO)%LDATA_DICE
LDATA_GROUND_DEPTH=>DATA_ISBA_MODEL(KTO)%LDATA_GROUND_DEPTH
LDATA_ROOT_DEPTH=>DATA_ISBA_MODEL(KTO)%LDATA_ROOT_DEPTH
LDATA_ROOT_EXTINCTION=>DATA_ISBA_MODEL(KTO)%LDATA_ROOT_EXTINCTION
LDATA_ROOT_LIN=>DATA_ISBA_MODEL(KTO)%LDATA_ROOT_LIN
LDATA_ROOTFRAC=>DATA_ISBA_MODEL(KTO)%LDATA_ROOTFRAC
LDATA_VEG=>DATA_ISBA_MODEL(KTO)%LDATA_VEG
LDATA_Z0=>DATA_ISBA_MODEL(KTO)%LDATA_Z0
LDATA_EMIS=>DATA_ISBA_MODEL(KTO)%LDATA_EMIS
LDATA_ALBNIR_VEG=>DATA_ISBA_MODEL(KTO)%LDATA_ALBNIR_VEG
LDATA_ALBVIS_VEG=>DATA_ISBA_MODEL(KTO)%LDATA_ALBVIS_VEG
LDATA_ALBUV_VEG=>DATA_ISBA_MODEL(KTO)%LDATA_ALBUV_VEG
LDATA_RSMIN=>DATA_ISBA_MODEL(KTO)%LDATA_RSMIN
LDATA_GAMMA=>DATA_ISBA_MODEL(KTO)%LDATA_GAMMA
LDATA_WRMAX_CF=>DATA_ISBA_MODEL(KTO)%LDATA_WRMAX_CF
LDATA_CV=>DATA_ISBA_MODEL(KTO)%LDATA_CV
LDATA_RGL=>DATA_ISBA_MODEL(KTO)%LDATA_RGL
LDATA_Z0_O_Z0H=>DATA_ISBA_MODEL(KTO)%LDATA_Z0_O_Z0H
LDATA_BSLAI=>DATA_ISBA_MODEL(KTO)%LDATA_BSLAI
LDATA_LAIMIN=>DATA_ISBA_MODEL(KTO)%LDATA_LAIMIN
LDATA_SEFOLD=>DATA_ISBA_MODEL(KTO)%LDATA_SEFOLD
LDATA_GMES=>DATA_ISBA_MODEL(KTO)%LDATA_GMES
LDATA_RE25=>DATA_ISBA_MODEL(KTO)%LDATA_RE25
LDATA_STRESS=>DATA_ISBA_MODEL(KTO)%LDATA_STRESS
LDATA_F2I=>DATA_ISBA_MODEL(KTO)%LDATA_F2I
LDATA_GC=>DATA_ISBA_MODEL(KTO)%LDATA_GC
LDATA_DMAX=>DATA_ISBA_MODEL(KTO)%LDATA_DMAX
LDATA_CE_NITRO=>DATA_ISBA_MODEL(KTO)%LDATA_CE_NITRO
LDATA_CF_NITRO=>DATA_ISBA_MODEL(KTO)%LDATA_CF_NITRO
LDATA_CNA_NITRO=>DATA_ISBA_MODEL(KTO)%LDATA_CNA_NITRO
LDATA_ALBNIR_SOIL=>DATA_ISBA_MODEL(KTO)%LDATA_ALBNIR_SOIL
LDATA_ALBVIS_SOIL=>DATA_ISBA_MODEL(KTO)%LDATA_ALBVIS_SOIL
LDATA_ALBUV_SOIL=>DATA_ISBA_MODEL(KTO)%LDATA_ALBUV_SOIL
LDATA_IRRIG=>DATA_ISBA_MODEL(KTO)%LDATA_IRRIG
LDATA_WATSUP=>DATA_ISBA_MODEL(KTO)%LDATA_WATSUP
XPAR_VEGTYPE=>DATA_ISBA_MODEL(KTO)%XPAR_VEGTYPE
XPAR_Z0_O_Z0H=>DATA_ISBA_MODEL(KTO)%XPAR_Z0_O_Z0H
XPAR_EMIS=>DATA_ISBA_MODEL(KTO)%XPAR_EMIS
XPAR_Z0=>DATA_ISBA_MODEL(KTO)%XPAR_Z0
XPAR_ALBNIR_VEG=>DATA_ISBA_MODEL(KTO)%XPAR_ALBNIR_VEG
XPAR_ALBVIS_VEG=>DATA_ISBA_MODEL(KTO)%XPAR_ALBVIS_VEG
XPAR_ALBUV_VEG=>DATA_ISBA_MODEL(KTO)%XPAR_ALBUV_VEG
XPAR_ALBNIR_SOIL=>DATA_ISBA_MODEL(KTO)%XPAR_ALBNIR_SOIL
XPAR_ALBVIS_SOIL=>DATA_ISBA_MODEL(KTO)%XPAR_ALBVIS_SOIL
XPAR_ALBUV_SOIL=>DATA_ISBA_MODEL(KTO)%XPAR_ALBUV_SOIL
XPAR_VEG=>DATA_ISBA_MODEL(KTO)%XPAR_VEG
XPAR_WRMAX_CF=>DATA_ISBA_MODEL(KTO)%XPAR_WRMAX_CF
XPAR_RSMIN=>DATA_ISBA_MODEL(KTO)%XPAR_RSMIN
XPAR_GAMMA=>DATA_ISBA_MODEL(KTO)%XPAR_GAMMA
XPAR_CV=>DATA_ISBA_MODEL(KTO)%XPAR_CV
XPAR_RGL=>DATA_ISBA_MODEL(KTO)%XPAR_RGL
XPAR_ROOTFRAC=>DATA_ISBA_MODEL(KTO)%XPAR_ROOTFRAC
XPAR_BSLAI=>DATA_ISBA_MODEL(KTO)%XPAR_BSLAI
XPAR_LAIMIN=>DATA_ISBA_MODEL(KTO)%XPAR_LAIMIN
XPAR_SEFOLD=>DATA_ISBA_MODEL(KTO)%XPAR_SEFOLD
XPAR_H_TREE=>DATA_ISBA_MODEL(KTO)%XPAR_H_TREE
XPAR_GMES=>DATA_ISBA_MODEL(KTO)%XPAR_GMES
XPAR_RE25=>DATA_ISBA_MODEL(KTO)%XPAR_RE25
LPAR_STRESS=>DATA_ISBA_MODEL(KTO)%LPAR_STRESS
XPAR_F2I=>DATA_ISBA_MODEL(KTO)%XPAR_F2I
XPAR_GC=>DATA_ISBA_MODEL(KTO)%XPAR_GC
XPAR_DMAX=>DATA_ISBA_MODEL(KTO)%XPAR_DMAX
XPAR_CE_NITRO=>DATA_ISBA_MODEL(KTO)%XPAR_CE_NITRO
XPAR_CF_NITRO=>DATA_ISBA_MODEL(KTO)%XPAR_CF_NITRO
XPAR_CNA_NITRO=>DATA_ISBA_MODEL(KTO)%XPAR_CNA_NITRO
XPAR_DG=>DATA_ISBA_MODEL(KTO)%XPAR_DG
XPAR_DICE=>DATA_ISBA_MODEL(KTO)%XPAR_DICE
XPAR_GROUND_DEPTH=>DATA_ISBA_MODEL(KTO)%XPAR_GROUND_DEPTH
XPAR_ROOT_DEPTH=>DATA_ISBA_MODEL(KTO)%XPAR_ROOT_DEPTH
XPAR_ROOT_EXTINCTION=>DATA_ISBA_MODEL(KTO)%XPAR_ROOT_EXTINCTION
XPAR_ROOT_LIN=>DATA_ISBA_MODEL(KTO)%XPAR_ROOT_LIN
XPAR_LAI=>DATA_ISBA_MODEL(KTO)%XPAR_LAI
XPAR_IRRIG=>DATA_ISBA_MODEL(KTO)%XPAR_IRRIG
XPAR_WATSUP=>DATA_ISBA_MODEL(KTO)%XPAR_WATSUP
IF (LHOOK) CALL DR_HOOK('MODD_DATA_ISBA_N:DATA_ISBA_GOTO_MODEL',1,ZHOOK_HANDLE)

END SUBROUTINE DATA_ISBA_GOTO_MODEL

SUBROUTINE DATA_ISBA_ALLOC(KMODEL)
INTEGER, INTENT(IN) :: KMODEL
INTEGER :: J
REAL(KIND=JPRB) :: ZHOOK_HANDLE
IF (LHOOK) CALL DR_HOOK("MODD_DATA_ISBA_N:DATA_ISBA_ALLOC",0,ZHOOK_HANDLE)
ALLOCATE(DATA_ISBA_MODEL(KMODEL))
DO J=1,KMODEL
  NULLIFY(DATA_ISBA_MODEL(J)%XPAR_VEGTYPE)
  NULLIFY(DATA_ISBA_MODEL(J)%XPAR_Z0_O_Z0H)
  NULLIFY(DATA_ISBA_MODEL(J)%XPAR_EMIS)
  NULLIFY(DATA_ISBA_MODEL(J)%XPAR_Z0)
  NULLIFY(DATA_ISBA_MODEL(J)%XPAR_ALBNIR_VEG)
  NULLIFY(DATA_ISBA_MODEL(J)%XPAR_ALBVIS_VEG)
  NULLIFY(DATA_ISBA_MODEL(J)%XPAR_ALBUV_VEG)
  NULLIFY(DATA_ISBA_MODEL(J)%XPAR_VEG)
  NULLIFY(DATA_ISBA_MODEL(J)%XPAR_WRMAX_CF)
  NULLIFY(DATA_ISBA_MODEL(J)%XPAR_RSMIN)
  NULLIFY(DATA_ISBA_MODEL(J)%XPAR_GAMMA)
  NULLIFY(DATA_ISBA_MODEL(J)%XPAR_CV)
  NULLIFY(DATA_ISBA_MODEL(J)%XPAR_RGL)
  NULLIFY(DATA_ISBA_MODEL(J)%XPAR_ROOTFRAC)
  NULLIFY(DATA_ISBA_MODEL(J)%XPAR_BSLAI)
  NULLIFY(DATA_ISBA_MODEL(J)%XPAR_LAIMIN)
  NULLIFY(DATA_ISBA_MODEL(J)%XPAR_SEFOLD)
  NULLIFY(DATA_ISBA_MODEL(J)%XPAR_H_TREE)
  NULLIFY(DATA_ISBA_MODEL(J)%XPAR_GMES)
  NULLIFY(DATA_ISBA_MODEL(J)%XPAR_RE25)
  NULLIFY(DATA_ISBA_MODEL(J)%LPAR_STRESS)
  NULLIFY(DATA_ISBA_MODEL(J)%XPAR_F2I)
  NULLIFY(DATA_ISBA_MODEL(J)%XPAR_GC)
  NULLIFY(DATA_ISBA_MODEL(J)%XPAR_DMAX)
  NULLIFY(DATA_ISBA_MODEL(J)%XPAR_CE_NITRO)
  NULLIFY(DATA_ISBA_MODEL(J)%XPAR_CF_NITRO)
  NULLIFY(DATA_ISBA_MODEL(J)%XPAR_CNA_NITRO)
  NULLIFY(DATA_ISBA_MODEL(J)%XPAR_DG)
  NULLIFY(DATA_ISBA_MODEL(J)%XPAR_DICE)
  NULLIFY(DATA_ISBA_MODEL(J)%XPAR_GROUND_DEPTH)  
  NULLIFY(DATA_ISBA_MODEL(J)%XPAR_ROOT_DEPTH)  
  NULLIFY(DATA_ISBA_MODEL(J)%XPAR_ROOT_EXTINCTION)  
  NULLIFY(DATA_ISBA_MODEL(J)%XPAR_ROOT_LIN)
  NULLIFY(DATA_ISBA_MODEL(J)%XPAR_ALBNIR_SOIL)
  NULLIFY(DATA_ISBA_MODEL(J)%XPAR_ALBVIS_SOIL)
  NULLIFY(DATA_ISBA_MODEL(J)%XPAR_ALBUV_SOIL)
  NULLIFY(DATA_ISBA_MODEL(J)%XPAR_LAI)
  NULLIFY(DATA_ISBA_MODEL(J)%XPAR_IRRIG)
  NULLIFY(DATA_ISBA_MODEL(J)%XPAR_WATSUP)  
ENDDO
DATA_ISBA_MODEL(:)%NTIME=0
DATA_ISBA_MODEL(:)%LDATA_MIXPAR=.FALSE.
DATA_ISBA_MODEL(:)%LDATA_VEGTYPE=.FALSE.
DATA_ISBA_MODEL(:)%LDATA_LAI=.FALSE.
DATA_ISBA_MODEL(:)%LDATA_H_TREE=.FALSE.
DATA_ISBA_MODEL(:)%LDATA_DG=.FALSE.
DATA_ISBA_MODEL(:)%LDATA_DICE=.FALSE.
DATA_ISBA_MODEL(:)%LDATA_GROUND_DEPTH=.FALSE.
DATA_ISBA_MODEL(:)%LDATA_ROOT_DEPTH=.FALSE.
DATA_ISBA_MODEL(:)%LDATA_ROOT_EXTINCTION=.FALSE.
DATA_ISBA_MODEL(:)%LDATA_ROOT_LIN=.FALSE.
DATA_ISBA_MODEL(:)%LDATA_ROOTFRAC=.FALSE.
DATA_ISBA_MODEL(:)%LDATA_VEG=.FALSE.
DATA_ISBA_MODEL(:)%LDATA_Z0=.FALSE.
DATA_ISBA_MODEL(:)%LDATA_EMIS=.FALSE.
DATA_ISBA_MODEL(:)%LDATA_ALBNIR_VEG=.FALSE.
DATA_ISBA_MODEL(:)%LDATA_ALBVIS_VEG=.FALSE.
DATA_ISBA_MODEL(:)%LDATA_ALBUV_VEG=.FALSE.
DATA_ISBA_MODEL(:)%LDATA_RSMIN=.FALSE.
DATA_ISBA_MODEL(:)%LDATA_GAMMA=.FALSE.
DATA_ISBA_MODEL(:)%LDATA_WRMAX_CF=.FALSE.
DATA_ISBA_MODEL(:)%LDATA_CV=.FALSE.
DATA_ISBA_MODEL(:)%LDATA_RGL=.FALSE.
DATA_ISBA_MODEL(:)%LDATA_Z0_O_Z0H=.FALSE.
DATA_ISBA_MODEL(:)%LDATA_BSLAI=.FALSE.
DATA_ISBA_MODEL(:)%LDATA_LAIMIN=.FALSE.
DATA_ISBA_MODEL(:)%LDATA_SEFOLD=.FALSE.
DATA_ISBA_MODEL(:)%LDATA_GMES=.FALSE.
DATA_ISBA_MODEL(:)%LDATA_RE25=.FALSE.
DATA_ISBA_MODEL(:)%LDATA_STRESS=.FALSE.
DATA_ISBA_MODEL(:)%LDATA_F2I=.FALSE.
DATA_ISBA_MODEL(:)%LDATA_GC=.FALSE.
DATA_ISBA_MODEL(:)%LDATA_DMAX=.FALSE.
DATA_ISBA_MODEL(:)%LDATA_CE_NITRO=.FALSE.
DATA_ISBA_MODEL(:)%LDATA_CF_NITRO=.FALSE.
DATA_ISBA_MODEL(:)%LDATA_CNA_NITRO=.FALSE.
DATA_ISBA_MODEL(:)%LDATA_ALBNIR_SOIL=.FALSE.
DATA_ISBA_MODEL(:)%LDATA_ALBVIS_SOIL=.FALSE.
DATA_ISBA_MODEL(:)%LDATA_ALBUV_SOIL=.FALSE.
DATA_ISBA_MODEL(:)%LDATA_IRRIG=.FALSE.
DATA_ISBA_MODEL(:)%LDATA_WATSUP=.FALSE.
IF (LHOOK) CALL DR_HOOK("MODD_DATA_ISBA_N:DATA_ISBA_ALLOC",1,ZHOOK_HANDLE)
END SUBROUTINE DATA_ISBA_ALLOC

SUBROUTINE DATA_ISBA_DEALLO
REAL(KIND=JPRB) :: ZHOOK_HANDLE
IF (LHOOK) CALL DR_HOOK("MODD_DATA_ISBA_N:DATA_ISBA_DEALLO",0,ZHOOK_HANDLE)
IF (ALLOCATED(DATA_ISBA_MODEL)) DEALLOCATE(DATA_ISBA_MODEL)
IF (LHOOK) CALL DR_HOOK("MODD_DATA_ISBA_N:DATA_ISBA_DEALLO",1,ZHOOK_HANDLE)
END SUBROUTINE DATA_ISBA_DEALLO

END MODULE MODD_DATA_ISBA_n
