!SURFEX_LIC Copyright 1994-2014 Meteo-France 
!SURFEX_LIC This is part of the SURFEX software governed by the CeCILL-C  licence
!SURFEX_LIC version 1. See LICENSE, CeCILL-C_V1-en.txt and CeCILL-C_V1-fr.txt
!SURFEX_LIC for details. version 1.
!     ####################
      MODULE MODD_WATFLUX_n
!     ####################
!
!!****  *MODD_WATFLUX_n - declaration of surface parameters for an inland water surface
!!
!!    PURPOSE
!!    -------
!     Declaration of surface parameters
!
!!
!!**  IMPLICIT ARGUMENTS
!!    ------------------
!!      None 
!!
!!    REFERENCE
!!    ---------
!!
!!    AUTHOR
!!    ------
!!	V. Masson  *Meteo France*
!!
!!    MODIFICATIONS
!!    -------------
!!      Original       01/2004
!
!*       0.   DECLARATIONS
!             ------------
!
USE MODD_TYPE_DATE_SURF
!
!
USE YOMHOOK   ,ONLY : LHOOK,   DR_HOOK
USE PARKIND1  ,ONLY : JPRB
!
IMPLICIT NONE

TYPE WATFLUX_t
!
! General surface: 
!
  REAL, POINTER, DIMENSION(:)   :: XZS     ! orography                     (m)
  REAL, POINTER, DIMENSION(:,:) :: XCOVER  ! fraction of each ecosystem    (-)
  LOGICAL, POINTER, DIMENSION(:):: LCOVER  ! GCOVER(i)=T --> ith cover field is not 0.
  LOGICAL                       :: LSBL    ! T: SBL scheme within the Surface Boundary Layer
!                                          ! F: no atmospheric layers below forcing level
  CHARACTER(LEN=4)              :: CWAT_ALB ! type of albedo
!
  LOGICAL                       :: LINTERPOL_TS ! Quadratic interpotalation of monthly TS
  CHARACTER(LEN=6)              :: CINTERPOL_TS ! Quadratic interpotalation of monthly TS
!
! Inland water:
!
  REAL, POINTER, DIMENSION(:) :: XTS       ! water surface temperature               (K)
  REAL, POINTER, DIMENSION(:) :: XTICE     ! water ice temperature
  REAL, POINTER, DIMENSION(:) :: XZ0       ! water surface roughness length          (-)
  REAL, POINTER, DIMENSION(:) :: XEMIS     ! water surface emissivity                (-)
  REAL, POINTER, DIMENSION(:) :: XDIR_ALB  ! water surface direct albedo             (-)
  REAL, POINTER, DIMENSION(:) :: XSCA_ALB  ! water surface diffuse albedo            (-)
  REAL, POINTER, DIMENSION(:) :: XICE_ALB  ! water ice albedo (for ESM coupling)     (-)
!
  REAL, POINTER, DIMENSION(:,:) :: XTS_MTH   ! Monthly water surface temperature               (K)
!
  REAL, POINTER, DIMENSION(:) :: XCPL_WATER_WIND ! 10m wind speed for ESM coupling
  REAL, POINTER, DIMENSION(:) :: XCPL_WATER_FWSU ! zonal wind stress for ESM coupling
  REAL, POINTER, DIMENSION(:) :: XCPL_WATER_FWSV ! meridian wind stress for ESM coupling
  REAL, POINTER, DIMENSION(:) :: XCPL_WATER_SNET ! Solar net heat flux
  REAL, POINTER, DIMENSION(:) :: XCPL_WATER_HEAT ! Non solar net heat flux
  REAL, POINTER, DIMENSION(:) :: XCPL_WATER_EVAP ! Evaporation for ESM coupling
  REAL, POINTER, DIMENSION(:) :: XCPL_WATER_RAIN ! Rainfall for ESM coupling
  REAL, POINTER, DIMENSION(:) :: XCPL_WATER_SNOW ! Snowfall for ESM coupling
  REAL, POINTER, DIMENSION(:) :: XCPL_WATER_FWSM ! wind stress module for ESM coupling
!
  REAL, POINTER, DIMENSION(:) :: XCPL_WATERICE_SNET ! solar net heat flux
  REAL, POINTER, DIMENSION(:) :: XCPL_WATERICE_HEAT ! Non solar net heat flux
  REAL, POINTER, DIMENSION(:) :: XCPL_WATERICE_EVAP ! Sublimation for ESM coupling
!
! Date:
!
  TYPE (DATE_TIME)                  :: TTIME         ! current date and time
!
! Time-step:
!
  REAL                              :: XTSTEP        ! time step
!
  REAL                              :: XOUT_TSTEP    ! output writing time step
!
!
END TYPE WATFLUX_t

TYPE(WATFLUX_t), ALLOCATABLE, TARGET, SAVE :: WATFLUX_MODEL(:)

REAL, POINTER, DIMENSION(:) :: XZS=>NULL()
!$OMP THREADPRIVATE(XZS)
REAL, POINTER, DIMENSION(:,:) :: XCOVER=>NULL()
!$OMP THREADPRIVATE(XCOVER)
LOGICAL, POINTER, DIMENSION(:):: LCOVER=>NULL()
!$OMP THREADPRIVATE(LCOVER)
LOGICAL, POINTER :: LSBL=>NULL()
!$OMP THREADPRIVATE(LSBL)
 CHARACTER(LEN=4), POINTER :: CWAT_ALB=>NULL()
!$OMP THREADPRIVATE(CWAT_ALB)
LOGICAL, POINTER :: LINTERPOL_TS=>NULL()
!$OMP THREADPRIVATE(LINTERPOL_TS)
 CHARACTER(LEN=6), POINTER :: CINTERPOL_TS=>NULL()
!$OMP THREADPRIVATE(CINTERPOL_TS)
REAL, POINTER, DIMENSION(:) :: XTS=>NULL()
!$OMP THREADPRIVATE(XTS)
REAL, POINTER, DIMENSION(:) :: XTICE=>NULL()
!$OMP THREADPRIVATE(XTICE)
REAL, POINTER, DIMENSION(:,:) :: XTS_MTH=>NULL()
!$OMP THREADPRIVATE(XTS_MTH)
REAL, POINTER, DIMENSION(:) :: XZ0=>NULL()
!$OMP THREADPRIVATE(XZ0)
REAL, POINTER, DIMENSION(:) :: XEMIS=>NULL()
!$OMP THREADPRIVATE(XEMIS)
REAL, POINTER, DIMENSION(:) :: XDIR_ALB=>NULL()
!$OMP THREADPRIVATE(XDIR_ALB)
REAL, POINTER, DIMENSION(:) :: XSCA_ALB=>NULL()
!$OMP THREADPRIVATE(XSCA_ALB)
REAL, POINTER, DIMENSION(:) :: XICE_ALB=>NULL()
!$OMP THREADPRIVATE(XICE_ALB)
REAL, POINTER, DIMENSION(:) :: XCPL_WATER_WIND=>NULL()
!$OMP THREADPRIVATE(XCPL_WATER_WIND)
REAL, POINTER, DIMENSION(:) :: XCPL_WATER_FWSU=>NULL()
!$OMP THREADPRIVATE(XCPL_WATER_FWSU)
REAL, POINTER, DIMENSION(:) :: XCPL_WATER_FWSV=>NULL()
!$OMP THREADPRIVATE(XCPL_WATER_FWSV)
REAL, POINTER, DIMENSION(:) :: XCPL_WATER_SNET=>NULL()
!$OMP THREADPRIVATE(XCPL_WATER_SNET)
REAL, POINTER, DIMENSION(:) :: XCPL_WATER_HEAT=>NULL()
!$OMP THREADPRIVATE(XCPL_WATER_HEAT)
REAL, POINTER, DIMENSION(:) :: XCPL_WATER_EVAP=>NULL()
!$OMP THREADPRIVATE(XCPL_WATER_EVAP)
REAL, POINTER, DIMENSION(:) :: XCPL_WATER_RAIN=>NULL()
!$OMP THREADPRIVATE(XCPL_WATER_RAIN)
REAL, POINTER, DIMENSION(:) :: XCPL_WATER_SNOW=>NULL()
!$OMP THREADPRIVATE(XCPL_WATER_SNOW)
REAL, POINTER, DIMENSION(:) :: XCPL_WATER_FWSM=>NULL()
!$OMP THREADPRIVATE(XCPL_WATER_FWSM)
REAL, POINTER, DIMENSION(:) :: XCPL_WATERICE_SNET=>NULL()
!$OMP THREADPRIVATE(XCPL_WATERICE_SNET)
REAL, POINTER, DIMENSION(:) :: XCPL_WATERICE_HEAT=>NULL()
!$OMP THREADPRIVATE(XCPL_WATERICE_HEAT)
REAL, POINTER, DIMENSION(:) :: XCPL_WATERICE_EVAP=>NULL()
!$OMP THREADPRIVATE(XCPL_WATERICE_EVAP)
TYPE (DATE_TIME), POINTER :: TTIME=>NULL()
!$OMP THREADPRIVATE(TTIME)
REAL, POINTER :: XTSTEP=>NULL()
!$OMP THREADPRIVATE(XTSTEP)
REAL, POINTER :: XOUT_TSTEP=>NULL()
!$OMP THREADPRIVATE(XOUT_TSTEP)

CONTAINS

SUBROUTINE WATFLUX_GOTO_MODEL(KFROM, KTO, LKFROM)
LOGICAL, INTENT(IN) :: LKFROM
INTEGER, INTENT(IN) :: KFROM, KTO
REAL(KIND=JPRB) :: ZHOOK_HANDLE
!
! Save current state for allocated arrays
IF (LKFROM) THEN
WATFLUX_MODEL(KFROM)%XZS=>XZS
WATFLUX_MODEL(KFROM)%XCOVER=>XCOVER
WATFLUX_MODEL(KFROM)%LCOVER=>LCOVER
WATFLUX_MODEL(KFROM)%XTS=>XTS
WATFLUX_MODEL(KFROM)%XTICE=>XTICE
WATFLUX_MODEL(KFROM)%XTS_MTH=>XTS_MTH
WATFLUX_MODEL(KFROM)%XZ0=>XZ0
WATFLUX_MODEL(KFROM)%XEMIS=>XEMIS
WATFLUX_MODEL(KFROM)%XDIR_ALB=>XDIR_ALB
WATFLUX_MODEL(KFROM)%XSCA_ALB=>XSCA_ALB
WATFLUX_MODEL(KFROM)%XICE_ALB=>XICE_ALB
WATFLUX_MODEL(KFROM)%XCPL_WATER_WIND=>XCPL_WATER_WIND
WATFLUX_MODEL(KFROM)%XCPL_WATER_FWSU=>XCPL_WATER_FWSU
WATFLUX_MODEL(KFROM)%XCPL_WATER_FWSV=>XCPL_WATER_FWSV
WATFLUX_MODEL(KFROM)%XCPL_WATER_SNET=>XCPL_WATER_SNET
WATFLUX_MODEL(KFROM)%XCPL_WATER_HEAT=>XCPL_WATER_HEAT
WATFLUX_MODEL(KFROM)%XCPL_WATER_EVAP=>XCPL_WATER_EVAP
WATFLUX_MODEL(KFROM)%XCPL_WATER_RAIN=>XCPL_WATER_RAIN
WATFLUX_MODEL(KFROM)%XCPL_WATER_SNOW=>XCPL_WATER_SNOW
WATFLUX_MODEL(KFROM)%XCPL_WATER_FWSM=>XCPL_WATER_FWSM
WATFLUX_MODEL(KFROM)%XCPL_WATERICE_SNET=>XCPL_WATERICE_SNET
WATFLUX_MODEL(KFROM)%XCPL_WATERICE_HEAT=>XCPL_WATERICE_HEAT
WATFLUX_MODEL(KFROM)%XCPL_WATERICE_EVAP=>XCPL_WATERICE_EVAP
ENDIF
!
! Current model is set to model KTO
IF (LHOOK) CALL DR_HOOK('MODD_WATFLUX_N:WATFLUX_GOTO_MODEL',0,ZHOOK_HANDLE)
XZS=>WATFLUX_MODEL(KTO)%XZS
XCOVER=>WATFLUX_MODEL(KTO)%XCOVER
LCOVER=>WATFLUX_MODEL(KTO)%LCOVER
LSBL=>WATFLUX_MODEL(KTO)%LSBL
CWAT_ALB=>WATFLUX_MODEL(KTO)%CWAT_ALB
LINTERPOL_TS=>WATFLUX_MODEL(KTO)%LINTERPOL_TS
CINTERPOL_TS=>WATFLUX_MODEL(KTO)%CINTERPOL_TS
XTS=>WATFLUX_MODEL(KTO)%XTS
XTICE=>WATFLUX_MODEL(KTO)%XTICE
XTS_MTH=>WATFLUX_MODEL(KTO)%XTS_MTH
XZ0=>WATFLUX_MODEL(KTO)%XZ0
XEMIS=>WATFLUX_MODEL(KTO)%XEMIS
XDIR_ALB=>WATFLUX_MODEL(KTO)%XDIR_ALB
XSCA_ALB=>WATFLUX_MODEL(KTO)%XSCA_ALB
XICE_ALB=>WATFLUX_MODEL(KTO)%XICE_ALB
XCPL_WATER_WIND=>WATFLUX_MODEL(KTO)%XCPL_WATER_WIND
XCPL_WATER_FWSU=>WATFLUX_MODEL(KTO)%XCPL_WATER_FWSU
XCPL_WATER_FWSV=>WATFLUX_MODEL(KTO)%XCPL_WATER_FWSV
XCPL_WATER_SNET=>WATFLUX_MODEL(KTO)%XCPL_WATER_SNET
XCPL_WATER_HEAT=>WATFLUX_MODEL(KTO)%XCPL_WATER_HEAT
XCPL_WATER_EVAP=>WATFLUX_MODEL(KTO)%XCPL_WATER_EVAP
XCPL_WATER_RAIN=>WATFLUX_MODEL(KTO)%XCPL_WATER_RAIN
XCPL_WATER_SNOW=>WATFLUX_MODEL(KTO)%XCPL_WATER_SNOW
XCPL_WATER_FWSM=>WATFLUX_MODEL(KTO)%XCPL_WATER_FWSM
XCPL_WATERICE_SNET=>WATFLUX_MODEL(KTO)%XCPL_WATERICE_SNET
XCPL_WATERICE_HEAT=>WATFLUX_MODEL(KTO)%XCPL_WATERICE_HEAT
XCPL_WATERICE_EVAP=>WATFLUX_MODEL(KTO)%XCPL_WATERICE_EVAP
TTIME=>WATFLUX_MODEL(KTO)%TTIME
XTSTEP=>WATFLUX_MODEL(KTO)%XTSTEP
XOUT_TSTEP=>WATFLUX_MODEL(KTO)%XOUT_TSTEP
IF (LHOOK) CALL DR_HOOK('MODD_WATFLUX_N:WATFLUX_GOTO_MODEL',1,ZHOOK_HANDLE)

END SUBROUTINE WATFLUX_GOTO_MODEL

SUBROUTINE WATFLUX_ALLOC(KMODEL)
INTEGER, INTENT(IN) :: KMODEL
INTEGER :: J
REAL(KIND=JPRB) :: ZHOOK_HANDLE
IF (LHOOK) CALL DR_HOOK("MODD_WATFLUX_N:WATFLUX_ALLOC",0,ZHOOK_HANDLE)
ALLOCATE(WATFLUX_MODEL(KMODEL))
DO J=1,KMODEL
  NULLIFY(WATFLUX_MODEL(J)%XZS)
  NULLIFY(WATFLUX_MODEL(J)%XCOVER)
  NULLIFY(WATFLUX_MODEL(J)%LCOVER)
  NULLIFY(WATFLUX_MODEL(J)%XTS)
  NULLIFY(WATFLUX_MODEL(J)%XTICE)
  NULLIFY(WATFLUX_MODEL(J)%XZ0)
  NULLIFY(WATFLUX_MODEL(J)%XEMIS)
  NULLIFY(WATFLUX_MODEL(J)%XDIR_ALB)
  NULLIFY(WATFLUX_MODEL(J)%XSCA_ALB)
  NULLIFY(WATFLUX_MODEL(J)%XICE_ALB)
  NULLIFY(WATFLUX_MODEL(J)%XTS_MTH)
  NULLIFY(WATFLUX_MODEL(J)%XCPL_WATER_WIND)
  NULLIFY(WATFLUX_MODEL(J)%XCPL_WATER_FWSU)
  NULLIFY(WATFLUX_MODEL(J)%XCPL_WATER_FWSV)
  NULLIFY(WATFLUX_MODEL(J)%XCPL_WATER_SNET)
  NULLIFY(WATFLUX_MODEL(J)%XCPL_WATER_HEAT)
  NULLIFY(WATFLUX_MODEL(J)%XCPL_WATER_EVAP)
  NULLIFY(WATFLUX_MODEL(J)%XCPL_WATER_RAIN)
  NULLIFY(WATFLUX_MODEL(J)%XCPL_WATER_SNOW)
  NULLIFY(WATFLUX_MODEL(J)%XCPL_WATER_FWSM)
  NULLIFY(WATFLUX_MODEL(J)%XCPL_WATERICE_SNET)
  NULLIFY(WATFLUX_MODEL(J)%XCPL_WATERICE_HEAT)
  NULLIFY(WATFLUX_MODEL(J)%XCPL_WATERICE_EVAP)
ENDDO
WATFLUX_MODEL(:)%LSBL=.FALSE.
WATFLUX_MODEL(:)%CWAT_ALB=' '
WATFLUX_MODEL(:)%LINTERPOL_TS=.FALSE.
WATFLUX_MODEL(:)%CINTERPOL_TS=' '
WATFLUX_MODEL(:)%XTSTEP=0.
WATFLUX_MODEL(:)%XOUT_TSTEP=0.
IF (LHOOK) CALL DR_HOOK("MODD_WATFLUX_N:WATFLUX_ALLOC",1,ZHOOK_HANDLE)
END SUBROUTINE WATFLUX_ALLOC

SUBROUTINE WATFLUX_DEALLO
REAL(KIND=JPRB) :: ZHOOK_HANDLE
IF (LHOOK) CALL DR_HOOK("MODD_WATFLUX_N:WATFLUX_DEALLO",0,ZHOOK_HANDLE)
IF (ALLOCATED(WATFLUX_MODEL)) DEALLOCATE(WATFLUX_MODEL)
IF (LHOOK) CALL DR_HOOK("MODD_WATFLUX_N:WATFLUX_DEALLO",1,ZHOOK_HANDLE)
END SUBROUTINE WATFLUX_DEALLO

END MODULE MODD_WATFLUX_n
