!SURFEX_LIC Copyright 1994-2014 Meteo-France 
!SURFEX_LIC This is part of the SURFEX software governed by the CeCILL-C  licence
!SURFEX_LIC version 1. See LICENSE, CeCILL-C_V1-en.txt and CeCILL-C_V1-fr.txt
!SURFEX_LIC for details. version 1.
!     #########
      SUBROUTINE READ_PGD_ISBA_PAR_n(HPROGRAM,KSIZE,OLAND_USE,HDIR)
!     ################################################
!
!!****  *READ_PGD_ISBA_PAR_n* - reads ISBA physiographic fields                     
!!
!!    PURPOSE
!!    -------
!!
!!**  METHOD
!!    ------
!!
!!    EXTERNAL
!!    --------
!!
!!
!!    IMPLICIT ARGUMENTS
!!    ------------------
!!
!!    REFERENCE
!!    ---------
!!
!!
!!    AUTHOR
!!    ------
!!	V. Masson   *Meteo France*	
!!
!!    MODIFICATIONS
!!    -------------
!!      Original    01/2003 
!!      P. Le Moigne 12/2004 : add type of photosynthesis 
!!      M.Moge    01/2016  using READ_SURF_FIELD2D/3D for 2D/3D surfex fields reads
!-------------------------------------------------------------------------------
!
!*       0.    DECLARATIONS
!              ------------
!
USE MODD_DATA_COVER_PAR, ONLY : NVEGTYPE
USE MODD_PREP,           ONLY : LINTERP
!
USE MODD_ISBA_GRID_n,    ONLY : NDIM
USE MODD_ISBA_n,         ONLY : LECOCLIMAP, NGROUND_LAYER
USE MODD_DATA_ISBA_n,    ONLY : NTIME, XPAR_VEG, XPAR_LAI,XPAR_RSMIN,XPAR_GAMMA,XPAR_WRMAX_CF, &
                                XPAR_RGL,XPAR_CV,XPAR_DG,XPAR_Z0,XPAR_Z0_O_Z0H,         &
                                XPAR_ALBNIR_VEG,XPAR_ALBVIS_VEG, XPAR_ALBUV_VEG,          &
                                XPAR_ALBNIR_SOIL,XPAR_ALBVIS_SOIL, XPAR_ALBUV_SOIL,       &
                                XPAR_EMIS, XPAR_DICE,                                      &
                                XPAR_VEGTYPE,XPAR_ROOTFRAC,                                &
                                XPAR_GMES,XPAR_BSLAI,XPAR_LAIMIN,XPAR_SEFOLD,XPAR_GC,   &
                                XPAR_DMAX, XPAR_F2I, LPAR_STRESS, XPAR_H_TREE,XPAR_RE25,&
                                XPAR_CE_NITRO,XPAR_CF_NITRO,XPAR_CNA_NITRO, &
                                XPAR_GROUND_DEPTH, XPAR_ROOT_DEPTH,               &
                                XPAR_ROOT_EXTINCTION, XPAR_ROOT_LIN,              &
                                LPAR_STRESS, XPAR_IRRIG, XPAR_WATSUP, &
                                LDATA_VEGTYPE, LDATA_LAI, LDATA_H_TREE, LDATA_DG, LDATA_ROOTFRAC,&  
                                LDATA_VEG, LDATA_Z0, LDATA_EMIS, LDATA_DICE, &
                                LDATA_RSMIN, LDATA_GAMMA, LDATA_WRMAX_CF, LDATA_RGL, &
                                LDATA_CV, LDATA_Z0_O_Z0H, &
                                LDATA_ALBNIR_VEG, LDATA_ALBVIS_VEG, LDATA_ALBUV_VEG, &
                                LDATA_ALBVIS_SOIL, LDATA_ALBNIR_SOIL, LDATA_ALBUV_SOIL, &
                                LDATA_GMES, LDATA_BSLAI, LDATA_SEFOLD, LDATA_GC, LDATA_DMAX, &
                                LDATA_RE25, LDATA_LAIMIN, LDATA_F2I, &
                                LDATA_CE_NITRO,LDATA_CF_NITRO, LDATA_CNA_NITRO,&
                                LDATA_STRESS, LDATA_IRRIG, LDATA_WATSUP  ,&
                                LDATA_GROUND_DEPTH, LDATA_ROOT_DEPTH,             &
                                LDATA_ROOT_EXTINCTION, LDATA_ROOT_LIN, LDATA_MIXPAR
!
USE MODI_GET_LUOUT
USE MODI_READ_SURF
USE MODI_READ_SURF_FIELD2D
USE MODI_HOR_INTERPOL
USE MODI_READ_SURF_ISBA_PAR_n
!
USE YOMHOOK   ,ONLY : LHOOK,   DR_HOOK
USE PARKIND1  ,ONLY : JPRB
!
IMPLICIT NONE
!
!*       0.1   Declarations of arguments
!              -------------------------
!
 CHARACTER(LEN=6),  INTENT(IN)  :: HPROGRAM ! program calling
INTEGER,           INTENT(IN)  :: KSIZE
LOGICAL,           INTENT(IN)  :: OLAND_USE ! 
 CHARACTER(LEN=1),OPTIONAL,INTENT(IN)  :: HDIR       ! type of field :
!                                                   ! 'H' : field with
!                                                   !       horizontal spatial dim.
!                                                   ! '-' : no horizontal dim.
!
!*       0.2   Declarations of local variables
!              -------------------------------
!
REAL, DIMENSION(KSIZE,NVEGTYPE) :: ZFIELD
REAL,    DIMENSION(:,:), ALLOCATABLE :: ZWORK
INTEGER           :: ILUOUT
INTEGER           :: ITIME
INTEGER           :: IRESP          ! IRESP  : return-code if a problem appears
 CHARACTER(LEN=12) :: YRECFM         ! Name of the article to be read
 CHARACTER(LEN=16) :: YRECFM2
 CHARACTER(LEN=100):: YCOMMENT       ! Comment string
 CHARACTER(LEN=1)  :: YDIR
INTEGER           :: JTIME          ! loop index
INTEGER           :: JLAYER         ! loop index
INTEGER           :: JPATCH         ! loop index
INTEGER           :: IVERSION       ! surface version
INTEGER           :: IBUGFIX
REAL(KIND=JPRB) :: ZHOOK_HANDLE
!
!
!-------------------------------------------------------------------------------
!
IF (LHOOK) CALL DR_HOOK('READ_PGD_ISBA_PAR_N',0,ZHOOK_HANDLE)
!
 CALL GET_LUOUT(HPROGRAM,ILUOUT)
!
YDIR = 'H'
IF (PRESENT(HDIR)) YDIR = HDIR
!
YRECFM='VERSION'
 CALL READ_SURF(HPROGRAM,YRECFM,IVERSION,IRESP)
WRITE(ILUOUT,*) 'read version ',IVERSION
!
YRECFM='BUG'
 CALL READ_SURF(HPROGRAM,YRECFM,IBUGFIX,IRESP)
!
LDATA_MIXPAR = .FALSE. 
!
IF (IVERSION<7 .AND. .NOT.LECOCLIMAP) THEN
  !
  LDATA_VEGTYPE=.TRUE.
  LDATA_VEG=.TRUE.
  LDATA_LAI=.TRUE.
  LDATA_Z0=.TRUE.
  LDATA_EMIS=.TRUE.
  LDATA_RSMIN=.TRUE.
  LDATA_GAMMA=.TRUE.
  LDATA_WRMAX_CF=.TRUE.
  LDATA_RGL=.TRUE.
  LDATA_CV=.TRUE.
  LDATA_Z0_O_Z0H=.TRUE.
  LDATA_DG=.TRUE.
  LDATA_ROOTFRAC=.TRUE.
  !
  LDATA_DICE=.FALSE.
  LDATA_GROUND_DEPTH=.FALSE.
  LDATA_ROOT_DEPTH=.FALSE.
  LDATA_ROOT_LIN=.FALSE.
  LDATA_ROOT_EXTINCTION=.FALSE.  
  !
  LDATA_ALBNIR_VEG=.TRUE.
  LDATA_ALBVIS_VEG=.TRUE.
  LDATA_ALBUV_VEG=.TRUE.
  LDATA_ALBNIR_SOIL=.TRUE.
  LDATA_ALBVIS_SOIL=.TRUE.
  LDATA_ALBUV_SOIL=.TRUE.
  LDATA_GMES=.TRUE.
  LDATA_BSLAI=.TRUE.
  LDATA_LAIMIN=.TRUE.
  LDATA_SEFOLD=.TRUE.
  LDATA_GC=.TRUE.
  LDATA_DMAX=.TRUE.
  LDATA_F2I=.TRUE.
  LDATA_STRESS=.TRUE.
  LDATA_H_TREE=.TRUE.
  LDATA_RE25=.TRUE.
  LDATA_CE_NITRO=.TRUE.
  LDATA_CF_NITRO=.TRUE.
  LDATA_CNA_NITRO=.TRUE.
  !
  LDATA_IRRIG=.FALSE.
  LDATA_WATSUP=.FALSE.
  !
ENDIF
!
IF (.NOT.OLAND_USE) THEN
  !
  IF (IVERSION>=7) THEN
    !
    YRECFM='L_VEGTYPE'
    YCOMMENT=YRECFM
    CALL READ_SURF(HPROGRAM,YRECFM,LDATA_VEGTYPE,IRESP,HCOMMENT=YCOMMENT)
    IF (LDATA_VEGTYPE) LDATA_MIXPAR = .TRUE.
    !
    YRECFM='L_VEG'
    YCOMMENT=YRECFM
    CALL READ_SURF(HPROGRAM,YRECFM,LDATA_VEG,IRESP,HCOMMENT=YCOMMENT)
    IF (LDATA_VEG) LDATA_MIXPAR = .TRUE.
    YRECFM='L_LAI'
    YCOMMENT=YRECFM
    CALL READ_SURF(HPROGRAM,YRECFM,LDATA_LAI,IRESP,HCOMMENT=YCOMMENT)
    IF (LDATA_LAI) LDATA_MIXPAR = .TRUE.
    YRECFM='L_Z0'
    YCOMMENT=YRECFM
    CALL READ_SURF(HPROGRAM,YRECFM,LDATA_Z0,IRESP,HCOMMENT=YCOMMENT)
    IF (LDATA_Z0) LDATA_MIXPAR = .TRUE.
    YRECFM='L_EMIS'
    YCOMMENT=YRECFM
    CALL READ_SURF(HPROGRAM,YRECFM,LDATA_EMIS,IRESP,HCOMMENT=YCOMMENT)
    IF (LDATA_EMIS) LDATA_MIXPAR = .TRUE.
    !
    YRECFM='L_RSMIN'
    YCOMMENT=YRECFM
    CALL READ_SURF(HPROGRAM,YRECFM,LDATA_RSMIN,IRESP,HCOMMENT=YCOMMENT)
    IF (LDATA_RSMIN) LDATA_MIXPAR = .TRUE.
    YRECFM='L_GAMMA'
    YCOMMENT=YRECFM
    CALL READ_SURF(HPROGRAM,YRECFM,LDATA_GAMMA,IRESP,HCOMMENT=YCOMMENT)
    IF (LDATA_GAMMA) LDATA_MIXPAR = .TRUE.
    YRECFM='L_WRMAX_CF'
    YCOMMENT=YRECFM
    CALL READ_SURF(HPROGRAM,YRECFM,LDATA_WRMAX_CF,IRESP,HCOMMENT=YCOMMENT)
    IF (LDATA_WRMAX_CF) LDATA_MIXPAR = .TRUE.
    YRECFM='L_RGL'
    YCOMMENT=YRECFM
    CALL READ_SURF(HPROGRAM,YRECFM,LDATA_RGL,IRESP,HCOMMENT=YCOMMENT)
    IF (LDATA_RGL) LDATA_MIXPAR = .TRUE.
    YRECFM='L_CV'
    YCOMMENT=YRECFM
    CALL READ_SURF(HPROGRAM,YRECFM,LDATA_CV,IRESP,HCOMMENT=YCOMMENT)
    IF (LDATA_CV) LDATA_MIXPAR = .TRUE.
    YRECFM='L_Z0_O_Z0H'
    YCOMMENT=YRECFM
    CALL READ_SURF(HPROGRAM,YRECFM,LDATA_Z0_O_Z0H,IRESP,HCOMMENT=YCOMMENT)
    IF (LDATA_Z0_O_Z0H) LDATA_MIXPAR = .TRUE.
    YRECFM='L_DG'
    YCOMMENT=YRECFM
    CALL READ_SURF(HPROGRAM,YRECFM,LDATA_DG,IRESP,HCOMMENT=YCOMMENT)
    IF (LDATA_DG) LDATA_MIXPAR = .TRUE.
    YRECFM='L_ROOTFRAC'
    YCOMMENT=YRECFM
    CALL READ_SURF(HPROGRAM,YRECFM,LDATA_ROOTFRAC,IRESP,HCOMMENT=YCOMMENT)
    IF (LDATA_ROOTFRAC) LDATA_MIXPAR = .TRUE.
    YRECFM='L_DICE'
    YCOMMENT=YRECFM
    CALL READ_SURF(HPROGRAM,YRECFM,LDATA_DICE,IRESP,HCOMMENT=YCOMMENT)
    IF (LDATA_DICE) LDATA_MIXPAR = .TRUE.
    !
    IF (IBUGFIX>=2) THEN
      YRECFM2='L_GROUND_DEPTH'
      IF (IBUGFIX>=3) YRECFM2='L_GROUND_DPT'
      YCOMMENT=YRECFM
      CALL READ_SURF(HPROGRAM,YRECFM2,LDATA_GROUND_DEPTH,IRESP,HCOMMENT=YCOMMENT)
      IF (LDATA_GROUND_DEPTH) LDATA_MIXPAR = .TRUE.
      YRECFM='L_ROOT_DEPTH'
      YCOMMENT=YRECFM
      CALL READ_SURF(HPROGRAM,YRECFM,LDATA_ROOT_DEPTH,IRESP,HCOMMENT=YCOMMENT)
      IF (LDATA_ROOT_DEPTH) LDATA_MIXPAR = .TRUE.
      YRECFM='L_ROOT_EXT'
      YCOMMENT=YRECFM
      CALL READ_SURF(HPROGRAM,YRECFM,LDATA_ROOT_EXTINCTION,IRESP,HCOMMENT=YCOMMENT)
      IF (LDATA_ROOT_EXTINCTION) LDATA_MIXPAR = .TRUE.
      YRECFM='L_ROOT_LIN'
      YCOMMENT=YRECFM
      CALL READ_SURF(HPROGRAM,YRECFM,LDATA_ROOT_LIN,IRESP,HCOMMENT=YCOMMENT)
      IF (LDATA_ROOT_LIN) LDATA_MIXPAR = .TRUE.
    ELSE
      LDATA_GROUND_DEPTH = .FALSE.
      LDATA_ROOT_DEPTH   = .FALSE.
      LDATA_ROOT_EXTINCTION = .FALSE.
      LDATA_ROOT_LIN = .FALSE.
    ENDIF
    !
    YRECFM='L_ALBNIR_VEG'
    YCOMMENT=YRECFM
    CALL READ_SURF(HPROGRAM,YRECFM,LDATA_ALBNIR_VEG,IRESP,HCOMMENT=YCOMMENT)
    IF (LDATA_ALBNIR_VEG) LDATA_MIXPAR = .TRUE.
    YRECFM='L_ALBVIS_VEG'
    YCOMMENT=YRECFM
    CALL READ_SURF(HPROGRAM,YRECFM,LDATA_ALBVIS_VEG,IRESP,HCOMMENT=YCOMMENT)
    IF (LDATA_ALBVIS_VEG) LDATA_MIXPAR = .TRUE.
    YRECFM='L_ALBUV_VEG'
    YCOMMENT=YRECFM
    CALL READ_SURF(HPROGRAM,YRECFM,LDATA_ALBUV_VEG,IRESP,HCOMMENT=YCOMMENT)
    IF (LDATA_ALBUV_VEG) LDATA_MIXPAR = .TRUE.
    YRECFM='L_ALBNIR_SOI'
    YCOMMENT=YRECFM
    CALL READ_SURF(HPROGRAM,YRECFM,LDATA_ALBNIR_SOIL,IRESP,HCOMMENT=YCOMMENT)
    IF (LDATA_ALBNIR_SOIL) LDATA_MIXPAR = .TRUE.
    YRECFM='L_ALBVIS_SOI'
    YCOMMENT=YRECFM
    CALL READ_SURF(HPROGRAM,YRECFM,LDATA_ALBVIS_SOIL,IRESP,HCOMMENT=YCOMMENT)
    IF (LDATA_ALBVIS_SOIL) LDATA_MIXPAR = .TRUE.
    YRECFM='L_ALBUV_SOI'
    YCOMMENT=YRECFM
    CALL READ_SURF(HPROGRAM,YRECFM,LDATA_ALBUV_SOIL,IRESP,HCOMMENT=YCOMMENT)
    IF (LDATA_ALBUV_SOIL) LDATA_MIXPAR = .TRUE.
    YRECFM='L_GMES'
    YCOMMENT=YRECFM
    CALL READ_SURF(HPROGRAM,YRECFM,LDATA_GMES,IRESP,HCOMMENT=YCOMMENT)
    IF (LDATA_GMES) LDATA_MIXPAR = .TRUE.
    YRECFM='L_BSLAI'
    YCOMMENT=YRECFM
    CALL READ_SURF(HPROGRAM,YRECFM,LDATA_BSLAI,IRESP,HCOMMENT=YCOMMENT)
    IF (LDATA_BSLAI) LDATA_MIXPAR = .TRUE.
    YRECFM='L_LAIMIN'
    YCOMMENT=YRECFM
    CALL READ_SURF(HPROGRAM,YRECFM,LDATA_LAIMIN,IRESP,HCOMMENT=YCOMMENT)
    IF (LDATA_LAIMIN) LDATA_MIXPAR = .TRUE.
    YRECFM='L_SEFOLD'
    YCOMMENT=YRECFM
    CALL READ_SURF(HPROGRAM,YRECFM,LDATA_SEFOLD,IRESP,HCOMMENT=YCOMMENT)
    IF (LDATA_SEFOLD) LDATA_MIXPAR = .TRUE.
    YRECFM='L_GC'
    YCOMMENT=YRECFM
    CALL READ_SURF(HPROGRAM,YRECFM,LDATA_GC,IRESP,HCOMMENT=YCOMMENT)
    IF (LDATA_GC) LDATA_MIXPAR = .TRUE.
    YRECFM='L_DMAX'
    YCOMMENT=YRECFM
    CALL READ_SURF(HPROGRAM,YRECFM,LDATA_DMAX,IRESP,HCOMMENT=YCOMMENT)
    IF (LDATA_DMAX) LDATA_MIXPAR = .TRUE.
    YRECFM='L_F2I'
    YCOMMENT=YRECFM
    CALL READ_SURF(HPROGRAM,YRECFM,LDATA_F2I,IRESP,HCOMMENT=YCOMMENT)
    IF (LDATA_F2I) LDATA_MIXPAR = .TRUE.
    YRECFM='L_STRESS'
    YCOMMENT=YRECFM
    CALL READ_SURF(HPROGRAM,YRECFM,LDATA_STRESS,IRESP,HCOMMENT=YCOMMENT)
    IF (LDATA_STRESS) LDATA_MIXPAR = .TRUE.
    YRECFM='L_H_TREE'
    YCOMMENT=YRECFM
    CALL READ_SURF(HPROGRAM,YRECFM,LDATA_H_TREE,IRESP,HCOMMENT=YCOMMENT)
    IF (LDATA_H_TREE) LDATA_MIXPAR = .TRUE.
    YRECFM='L_RE25'
    YCOMMENT=YRECFM
    CALL READ_SURF(HPROGRAM,YRECFM,LDATA_RE25,IRESP,HCOMMENT=YCOMMENT)
    IF (LDATA_RE25) LDATA_MIXPAR = .TRUE.
    YRECFM='L_CE_NITRO'
    YCOMMENT=YRECFM
    CALL READ_SURF(HPROGRAM,YRECFM,LDATA_CE_NITRO,IRESP,HCOMMENT=YCOMMENT)
    IF (LDATA_CE_NITRO) LDATA_MIXPAR = .TRUE.
    YRECFM='L_CF_NITRO'
    YCOMMENT=YRECFM
    CALL READ_SURF(HPROGRAM,YRECFM,LDATA_CF_NITRO,IRESP,HCOMMENT=YCOMMENT)
    IF (LDATA_CF_NITRO) LDATA_MIXPAR = .TRUE.
    YRECFM='L_CNA_NITRO'
    YCOMMENT=YRECFM
    CALL READ_SURF(HPROGRAM,YRECFM,LDATA_CNA_NITRO,IRESP,HCOMMENT=YCOMMENT)
    IF (LDATA_CNA_NITRO) LDATA_MIXPAR = .TRUE.
    YRECFM='L_IRRIG'
    YCOMMENT=YRECFM
    CALL READ_SURF(HPROGRAM,YRECFM,LDATA_IRRIG,IRESP,HCOMMENT=YCOMMENT)
    IF (LDATA_IRRIG) LDATA_MIXPAR = .TRUE.
    YRECFM='L_WATSUP'
    YCOMMENT=YRECFM
    CALL READ_SURF(HPROGRAM,YRECFM,LDATA_WATSUP,IRESP,HCOMMENT=YCOMMENT)
    IF (LDATA_WATSUP) LDATA_MIXPAR = .TRUE.
    !
  ENDIF
  !
  IF (ALLOCATED(LINTERP)) LINTERP(:) = .TRUE.
  !
  IF (LDATA_VEGTYPE) THEN
    YRECFM='D_VEGTYPE'
    CALL READ_SURF_FIELD2D(HPROGRAM,ZFIELD(:,:),YRECFM,HCOMMENT=YCOMMENT,HDIR=YDIR)
    ALLOCATE(XPAR_VEGTYPE   (NDIM,NVEGTYPE))
    IF (NDIM/=KSIZE) THEN
      CALL HOR_INTERPOL(ILUOUT,ZFIELD,XPAR_VEGTYPE)
    ELSE
      XPAR_VEGTYPE(:,:) = ZFIELD(:,:)
    ENDIF
  ENDIF
!
  IF (LDATA_LAI .OR. LDATA_VEG .OR. LDATA_Z0 .OR. LDATA_EMIS) THEN
    YRECFM='NDATA_TIME'
    CALL READ_SURF(HPROGRAM,YRECFM,NTIME,IRESP,HCOMMENT=YCOMMENT)
    ITIME = NTIME
  ELSE
    NTIME = 1
  ENDIF
!  
  IF (LDATA_VEG) THEN
    ALLOCATE(XPAR_VEG(NDIM,NTIME,NVEGTYPE))           
    DO JTIME=1,ITIME
      WRITE(YRECFM,FMT='(A7,I2.2)') 'D_VEG_T',JTIME
      CALL READ_SURF_ISBA_PAR_n(HPROGRAM,YRECFM,ILUOUT,KSIZE,XPAR_VEG(:,JTIME,:),IRESP,IVERSION,&
                                HCOMMENT=YCOMMENT,HDIR=YDIR)       
    END DO
  ENDIF
!
  IF (LDATA_LAI) THEN
    ALLOCATE(XPAR_LAI(NDIM,NTIME,NVEGTYPE))
    DO JTIME=1,ITIME
      WRITE(YRECFM,FMT='(A7,I2.2)') 'D_LAI_T',JTIME
      CALL READ_SURF_ISBA_PAR_n(HPROGRAM,YRECFM,ILUOUT,KSIZE,XPAR_LAI(:,JTIME,:),IRESP,IVERSION,&
                                HCOMMENT=YCOMMENT,HDIR=YDIR)
    END DO
  ENDIF
!
  IF (LDATA_Z0) THEN
    ALLOCATE(XPAR_Z0        (NDIM,NTIME,NVEGTYPE))
    DO JTIME=1,ITIME
      WRITE(YRECFM,FMT='(A6,I2.2)') 'D_Z0_T',JTIME
      CALL READ_SURF_ISBA_PAR_n(HPROGRAM,YRECFM,ILUOUT,KSIZE,XPAR_Z0(:,JTIME,:),IRESP,IVERSION,&
                                HCOMMENT=YCOMMENT,HDIR=YDIR)
    END DO
  ENDIF
!
  IF (LDATA_EMIS) THEN
    ALLOCATE(XPAR_EMIS      (NDIM,NTIME,NVEGTYPE))
    DO JTIME=1,ITIME
      WRITE(YRECFM,FMT='(A8,I2.2)') 'D_EMIS_T',JTIME
      CALL READ_SURF_ISBA_PAR_n(HPROGRAM,YRECFM,ILUOUT,KSIZE,XPAR_EMIS(:,JTIME,:),IRESP,IVERSION,&
                                HCOMMENT=YCOMMENT,HDIR=YDIR)
    END DO
  ENDIF
!
  IF (LDATA_RSMIN) THEN
    ALLOCATE(XPAR_RSMIN     (NDIM,NVEGTYPE))
    YRECFM='D_RSMIN'
    CALL READ_SURF_ISBA_PAR_n(HPROGRAM,YRECFM,ILUOUT,KSIZE,XPAR_RSMIN(:,:),IRESP,IVERSION,&
                              HCOMMENT=YCOMMENT,HDIR=YDIR)
  ENDIF
!
  IF (LDATA_GAMMA) THEN
    ALLOCATE(XPAR_GAMMA     (NDIM,NVEGTYPE))
    YRECFM='D_GAMMA'
    CALL READ_SURF_ISBA_PAR_n(HPROGRAM,YRECFM,ILUOUT,KSIZE,XPAR_GAMMA(:,:),IRESP,IVERSION,&
                              HCOMMENT=YCOMMENT,HDIR=YDIR)
  ENDIF
!
  IF (LDATA_WRMAX_CF) THEN
    ALLOCATE(XPAR_WRMAX_CF  (NDIM,NVEGTYPE))
    YRECFM='D_WRMAX_CF'
    CALL READ_SURF_ISBA_PAR_n(HPROGRAM,YRECFM,ILUOUT,KSIZE,XPAR_WRMAX_CF(:,:),IRESP,IVERSION,&
                              HCOMMENT=YCOMMENT,HDIR=YDIR)
  ENDIF
!
  IF (LDATA_RGL) THEN
    ALLOCATE(XPAR_RGL       (NDIM,NVEGTYPE))
    YRECFM='D_RGL'
    CALL READ_SURF_ISBA_PAR_n(HPROGRAM,YRECFM,ILUOUT,KSIZE,XPAR_RGL(:,:),IRESP,IVERSION,&
                              HCOMMENT=YCOMMENT,HDIR=YDIR)
  ENDIF
!
  IF (LDATA_CV) THEN
    ALLOCATE(XPAR_CV        (NDIM,NVEGTYPE))
    YRECFM='D_CV'
    CALL READ_SURF_ISBA_PAR_n(HPROGRAM,YRECFM,ILUOUT,KSIZE,XPAR_CV(:,:),IRESP,IVERSION,&
                              HCOMMENT=YCOMMENT,HDIR=YDIR)
  ENDIF
!
  IF (LDATA_Z0_O_Z0H) THEN
    ALLOCATE(XPAR_Z0_O_Z0H  (NDIM,NVEGTYPE))
    YRECFM='D_Z0_O_Z0H'
    CALL READ_SURF_ISBA_PAR_n(HPROGRAM,YRECFM,ILUOUT,KSIZE,XPAR_Z0_O_Z0H(:,:),IRESP,IVERSION,&
                              HCOMMENT=YCOMMENT,HDIR=YDIR)
  ENDIF
!
  IF (LDATA_DG) THEN
    ALLOCATE(XPAR_DG        (NDIM,NGROUND_LAYER,NVEGTYPE))
    ALLOCATE(ZWORK(SIZE(XPAR_DG,1),SIZE(XPAR_DG,3)))
    DO JLAYER=1,SIZE(XPAR_DG,2)
      IF (JLAYER<10)  WRITE(YRECFM,FMT='(A4,I1.1)') 'D_DG',JLAYER
      IF (JLAYER>=10) WRITE(YRECFM,FMT='(A4,I2.2)') 'D_DG',JLAYER
      CALL READ_SURF_ISBA_PAR_n(HPROGRAM,YRECFM,ILUOUT,KSIZE,ZWORK,IRESP,IVERSION,&
                                HCOMMENT=YCOMMENT,HDIR=YDIR)
      DO JPATCH=1,SIZE(XPAR_DG,3)
        XPAR_DG(:,JLAYER,JPATCH) = ZWORK(:,JPATCH)
      END DO
    END DO
    DEALLOCATE(ZWORK)
  ENDIF
!
  IF (LDATA_ROOTFRAC) THEN
    ALLOCATE(XPAR_ROOTFRAC  (NDIM,NGROUND_LAYER,NVEGTYPE))
    ALLOCATE(ZWORK(SIZE(XPAR_ROOTFRAC,1),SIZE(XPAR_ROOTFRAC,3)))
    DO JLAYER=1,SIZE(XPAR_ROOTFRAC,2)
      IF (JLAYER<10)  WRITE(YRECFM,FMT='(A10,I1.1)') 'D_ROOTFRAC',JLAYER
      IF (JLAYER>=10) WRITE(YRECFM,FMT='(A10,I2.2)') 'D_ROOTFRAC',JLAYER
        CALL READ_SURF_ISBA_PAR_n(HPROGRAM,YRECFM,ILUOUT,KSIZE,ZWORK,IRESP,IVERSION,&
                                  HCOMMENT=YCOMMENT,HDIR=YDIR)
      DO JPATCH=1,SIZE(XPAR_ROOTFRAC,3)
        XPAR_ROOTFRAC(:,JLAYER,JPATCH) = ZWORK(:,JPATCH)
      END DO
    END DO
    DEALLOCATE(ZWORK)
  ENDIF
!
  IF (LDATA_DICE) THEN
    ALLOCATE(XPAR_DICE      (NDIM,NVEGTYPE))
    YRECFM='D_DICE'
    CALL READ_SURF_ISBA_PAR_n(HPROGRAM,YRECFM,ILUOUT,KSIZE,XPAR_DICE(:,:),IRESP,IVERSION,&
                              HCOMMENT=YCOMMENT,HDIR=YDIR)
  ENDIF
!
  IF (LDATA_GROUND_DEPTH) THEN
    ALLOCATE(XPAR_GROUND_DEPTH(NDIM,NVEGTYPE))
    YRECFM2='D_GROUND_DEPTH'
    IF (IVERSION>7 .OR. IVERSION==7 .AND. IBUGFIX>=3) YRECFM2='D_GROUND_DPT'
    CALL READ_SURF_ISBA_PAR_n(HPROGRAM,YRECFM2,ILUOUT,KSIZE,XPAR_GROUND_DEPTH(:,:),IRESP,IVERSION,&
                              HCOMMENT=YCOMMENT,HDIR=YDIR)
  ENDIF
!
  IF (LDATA_ROOT_DEPTH) THEN
    ALLOCATE(XPAR_ROOT_DEPTH(NDIM,NVEGTYPE))
    YRECFM='D_ROOT_DEPTH'
    CALL READ_SURF_ISBA_PAR_n(HPROGRAM,YRECFM,ILUOUT,KSIZE,XPAR_ROOT_DEPTH(:,:),IRESP,IVERSION,&
                              HCOMMENT=YCOMMENT,HDIR=YDIR)
  ENDIF
!
  IF (LDATA_ROOT_EXTINCTION) THEN
    ALLOCATE(XPAR_ROOT_EXTINCTION(NDIM,NVEGTYPE))
    YRECFM='D_ROOT_EXT'
    CALL READ_SURF_ISBA_PAR_n(HPROGRAM,YRECFM,ILUOUT,KSIZE,XPAR_ROOT_EXTINCTION(:,:),IRESP,IVERSION,&
                              HCOMMENT=YCOMMENT,HDIR=YDIR)
  ENDIF
!
  IF (LDATA_ROOT_LIN) THEN
    ALLOCATE(XPAR_ROOT_LIN(NDIM,NVEGTYPE))
    YRECFM='D_ROOT_LIN'
    CALL READ_SURF_ISBA_PAR_n(HPROGRAM,YRECFM,ILUOUT,KSIZE,XPAR_ROOT_LIN(:,:),IRESP,IVERSION,&
                              HCOMMENT=YCOMMENT,HDIR=YDIR)
  ENDIF
!
  IF (LDATA_ALBNIR_VEG) THEN
    ALLOCATE(XPAR_ALBNIR_VEG(NDIM,NVEGTYPE))
    YRECFM='D_ALBNIR_VEG'
    CALL READ_SURF_ISBA_PAR_n(HPROGRAM,YRECFM,ILUOUT,KSIZE,XPAR_ALBNIR_VEG(:,:),IRESP,IVERSION,&
                              HCOMMENT=YCOMMENT,HDIR=YDIR)
  ENDIF
!
  IF (LDATA_ALBVIS_VEG) THEN
    ALLOCATE(XPAR_ALBVIS_VEG(NDIM,NVEGTYPE))
    YRECFM='D_ALBVIS_VEG'
    CALL READ_SURF_ISBA_PAR_n(HPROGRAM,YRECFM,ILUOUT,KSIZE,XPAR_ALBVIS_VEG(:,:),IRESP,IVERSION,&
                              HCOMMENT=YCOMMENT,HDIR=YDIR)
  ENDIF
!
  IF (LDATA_ALBUV_VEG) THEN
    ALLOCATE(XPAR_ALBUV_VEG (NDIM,NVEGTYPE))
    YRECFM='D_ALBUV_VEG'
    CALL READ_SURF_ISBA_PAR_n(HPROGRAM,YRECFM,ILUOUT,KSIZE,XPAR_ALBUV_VEG(:,:),IRESP,IVERSION,&
                              HCOMMENT=YCOMMENT,HDIR=YDIR)
  ENDIF
!
  IF (LDATA_ALBNIR_SOIL) THEN
    ALLOCATE(XPAR_ALBNIR_SOIL(NDIM,NVEGTYPE))
    YRECFM='D_ALBNIR_SOI'
    CALL READ_SURF_ISBA_PAR_n(HPROGRAM,YRECFM,ILUOUT,KSIZE,XPAR_ALBNIR_SOIL(:,:),IRESP,IVERSION,&
                              HCOMMENT=YCOMMENT,HDIR=YDIR)
  ENDIF
!
  IF (LDATA_ALBVIS_SOIL) THEN
    ALLOCATE(XPAR_ALBVIS_SOIL(NDIM,NVEGTYPE))
    YRECFM='D_ALBVIS_SOI'
    CALL READ_SURF_ISBA_PAR_n(HPROGRAM,YRECFM,ILUOUT,KSIZE,XPAR_ALBVIS_SOIL(:,:),IRESP,IVERSION,&
                              HCOMMENT=YCOMMENT,HDIR=YDIR)
  ENDIF
!
  IF (LDATA_ALBUV_SOIL) THEN
    ALLOCATE(XPAR_ALBUV_SOIL (NDIM,NVEGTYPE))
    YRECFM='D_ALBUV_SOI'
    CALL READ_SURF_ISBA_PAR_n(HPROGRAM,YRECFM,ILUOUT,KSIZE,XPAR_ALBUV_SOIL(:,:),IRESP,IVERSION,&
                              HCOMMENT=YCOMMENT,HDIR=YDIR)
  ENDIF
!
  IF (LDATA_GMES) THEN
    ALLOCATE(XPAR_GMES      (NDIM,NVEGTYPE))
    YRECFM='D_GMES'
    CALL READ_SURF_ISBA_PAR_n(HPROGRAM,YRECFM,ILUOUT,KSIZE,XPAR_GMES(:,:),IRESP,IVERSION,&
                              HCOMMENT=YCOMMENT,HDIR=YDIR)
  ENDIF
!
  IF (LDATA_BSLAI) THEN
    ALLOCATE(XPAR_BSLAI     (NDIM,NVEGTYPE))
    YRECFM='D_BSLAI'
    CALL READ_SURF_ISBA_PAR_n(HPROGRAM,YRECFM,ILUOUT,KSIZE,XPAR_BSLAI(:,:),IRESP,IVERSION,&
                              HCOMMENT=YCOMMENT,HDIR=YDIR)
  ENDIF
!
  IF (LDATA_LAIMIN) THEN
    ALLOCATE(XPAR_LAIMIN    (NDIM,NVEGTYPE))
    YRECFM='D_LAIMIN'
    CALL READ_SURF_ISBA_PAR_n(HPROGRAM,YRECFM,ILUOUT,KSIZE,XPAR_LAIMIN(:,:),IRESP,IVERSION,&
                              HCOMMENT=YCOMMENT,HDIR=YDIR)
  ENDIF
!
  IF (LDATA_SEFOLD) THEN
    ALLOCATE(XPAR_SEFOLD    (NDIM,NVEGTYPE))
    YRECFM='D_SEFOLD'
    CALL READ_SURF_ISBA_PAR_n(HPROGRAM,YRECFM,ILUOUT,KSIZE,XPAR_SEFOLD(:,:),IRESP,IVERSION,&
                              HCOMMENT=YCOMMENT,HDIR=YDIR)
  ENDIF
!
  IF (LDATA_GC) THEN
    ALLOCATE(XPAR_GC        (NDIM,NVEGTYPE))
    YRECFM='D_GC'
    CALL READ_SURF_ISBA_PAR_n(HPROGRAM,YRECFM,ILUOUT,KSIZE,XPAR_GC(:,:),IRESP,IVERSION,&
                              HCOMMENT=YCOMMENT,HDIR=YDIR)
  ENDIF
!
  IF (LDATA_DMAX) THEN
    ALLOCATE(XPAR_DMAX      (NDIM,NVEGTYPE))
    YRECFM='D_DMAX'
    CALL READ_SURF_ISBA_PAR_n(HPROGRAM,YRECFM,ILUOUT,KSIZE,XPAR_DMAX(:,:),IRESP,IVERSION,&
                              HCOMMENT=YCOMMENT,HDIR=YDIR)
  ENDIF
!
  IF (LDATA_F2I) THEN
    ALLOCATE(XPAR_F2I       (NDIM,NVEGTYPE))
    YRECFM='D_F2I'
    CALL READ_SURF_ISBA_PAR_n(HPROGRAM,YRECFM,ILUOUT,KSIZE,XPAR_F2I(:,:),IRESP,IVERSION,&
                              HCOMMENT=YCOMMENT,HDIR=YDIR)
  ENDIF
!
  IF (LDATA_STRESS) THEN
    ALLOCATE(LPAR_STRESS   (NDIM,NVEGTYPE))
    ALLOCATE(ZWORK(SIZE(LPAR_STRESS,1),SIZE(LPAR_STRESS,2)))
    YRECFM='D_STRESS'
    CALL READ_SURF_ISBA_PAR_n(HPROGRAM,YRECFM,ILUOUT,KSIZE,ZWORK(:,:),IRESP,IVERSION,&
                              HCOMMENT=YCOMMENT,HDIR=YDIR)
    LPAR_STRESS = .FALSE.
    WHERE(ZWORK==1.) LPAR_STRESS = .TRUE.
    DEALLOCATE(ZWORK)
  ENDIF
!
  IF (LDATA_H_TREE) THEN
    ALLOCATE(XPAR_H_TREE    (NDIM,NVEGTYPE))
    YRECFM='D_H_TREE'
    CALL READ_SURF_ISBA_PAR_n(HPROGRAM,YRECFM,ILUOUT,KSIZE,XPAR_H_TREE(:,:),IRESP,IVERSION,&
                              HCOMMENT=YCOMMENT,HDIR=YDIR)
  ENDIF
!
  IF (LDATA_RE25) THEN
    ALLOCATE(XPAR_RE25      (NDIM,NVEGTYPE))
    YRECFM='D_RE25'
    CALL READ_SURF_ISBA_PAR_n(HPROGRAM,YRECFM,ILUOUT,KSIZE,XPAR_RE25(:,:),IRESP,IVERSION,&
                              HCOMMENT=YCOMMENT,HDIR=YDIR)
  ENDIF
!
  IF (LDATA_CE_NITRO) THEN
    ALLOCATE(XPAR_CE_NITRO  (NDIM,NVEGTYPE))
    YRECFM='D_CE_NITRO'
    CALL READ_SURF_ISBA_PAR_n(HPROGRAM,YRECFM,ILUOUT,KSIZE,XPAR_CE_NITRO(:,:),IRESP,IVERSION,&
                              HCOMMENT=YCOMMENT,HDIR=YDIR)
  ENDIF
!
  IF (LDATA_CF_NITRO) THEN
    ALLOCATE(XPAR_CF_NITRO  (NDIM,NVEGTYPE))
    YRECFM='D_CF_NITRO'
    CALL READ_SURF_ISBA_PAR_n(HPROGRAM,YRECFM,ILUOUT,KSIZE,XPAR_CF_NITRO(:,:),IRESP,IVERSION,&
                              HCOMMENT=YCOMMENT,HDIR=YDIR)
  ENDIF
!
  IF (LDATA_CNA_NITRO) THEN
    ALLOCATE(XPAR_CNA_NITRO (NDIM,NVEGTYPE))
    YRECFM='D_CNA_NITRO'
    CALL READ_SURF_ISBA_PAR_n(HPROGRAM,YRECFM,ILUOUT,KSIZE,XPAR_CNA_NITRO(:,:),IRESP,IVERSION,&
                              HCOMMENT=YCOMMENT,HDIR=YDIR)
  ENDIF
!
  IF (LDATA_IRRIG) THEN
    ALLOCATE(XPAR_IRRIG     (NDIM,NTIME,NVEGTYPE))
    DO JTIME=1,ITIME
      WRITE(YRECFM,FMT='(A9,I2.2)') 'D_IRRIG_T',JTIME
        CALL READ_SURF_ISBA_PAR_n(HPROGRAM,YRECFM,ILUOUT,KSIZE,XPAR_IRRIG(:,JTIME,:),IRESP,IVERSION,&
                                  HCOMMENT=YCOMMENT,HDIR=YDIR)
    END DO
  ENDIF
!
  IF (LDATA_WATSUP) THEN
    ALLOCATE(XPAR_WATSUP     (NDIM,NTIME,NVEGTYPE))
    DO JTIME=1,ITIME
      WRITE(YRECFM,FMT='(A10,I2.2)') 'D_WATSUP_T',JTIME
        CALL READ_SURF_ISBA_PAR_n(HPROGRAM,YRECFM,ILUOUT,KSIZE,XPAR_WATSUP(:,JTIME,:),IRESP,IVERSION,&
                                  HCOMMENT=YCOMMENT,HDIR=YDIR)
    END DO
  ENDIF
!
ENDIF
!
IF (LHOOK) CALL DR_HOOK('READ_PGD_ISBA_PAR_N',1,ZHOOK_HANDLE)
!
!-------------------------------------------------------------------------------
!
END SUBROUTINE READ_PGD_ISBA_PAR_n
